@@ -174,8 +174,8 @@ ValaCCodeDeclaration* vala_ccode_declaration_construct (GType object_type, const
 GType vala_ccode_declarator_get_type (void);
 void vala_ccode_declaration_add_declarator (ValaCCodeDeclaration* self, ValaCCodeDeclarator* decl);
 GType vala_ccode_expression_get_type (void);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer);
-ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_new (const char* name, ValaCCodeExpression* initializer, const char* declarator_suffix);
+ValaCCodeVariableDeclarator* vala_ccode_variable_declarator_construct (GType object_type, const char* name, ValaCCodeExpression* initializer, const char* declarator_suffix);
 GType vala_ccode_variable_declarator_get_type (void);
 void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name, const char* name);
 void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
@@ -224,14 +224,14 @@ void vala_ccode_struct_add_declaration (ValaCCodeStruct* self, ValaCCodeDeclarat
  */
 void vala_ccode_struct_add_field (ValaCCodeStruct* self, const char* type_name, const char* name) {
 	ValaCCodeDeclaration* decl;
-	ValaCCodeVariableDeclarator* _tmp0;
+	ValaCCodeVariableDeclarator* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (type_name != NULL);
 	g_return_if_fail (name != NULL);
 	decl = vala_ccode_declaration_new (type_name);
-	_tmp0 = NULL;
-	vala_ccode_declaration_add_declarator (decl, (ValaCCodeDeclarator*) (_tmp0 = vala_ccode_variable_declarator_new (name, NULL)));
-	(_tmp0 == NULL) ? NULL : (_tmp0 = (vala_ccode_node_unref (_tmp0), NULL));
+	_tmp0_ = NULL;
+	vala_ccode_declaration_add_declarator (decl, (ValaCCodeDeclarator*) (_tmp0_ = vala_ccode_variable_declarator_new (name, NULL, NULL)));
+	(_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_ccode_node_unref (_tmp0_), NULL));
 	vala_ccode_struct_add_declaration (self, decl);
 	(decl == NULL) ? NULL : (decl = (vala_ccode_node_unref (decl), NULL));
 }
@@ -269,12 +269,12 @@ const char* vala_ccode_struct_get_name (ValaCCodeStruct* self) {
 
 
 void vala_ccode_struct_set_name (ValaCCodeStruct* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_name = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_name = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_name = (g_free (self->priv->_name), NULL), _tmp2_);
 }
 
 
