@@ -1,6 +1,6 @@
 /* valaccodewriter.vala
  *
- * Copyright (C) 2006-2008  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -20,14 +20,60 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <ccode/valaccodewriter.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
 #include <stdio.h>
 #include <glib/gstdio.h>
-#include <ccode/valaccodelinedirective.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define VALA_TYPE_CCODE_WRITER (vala_ccode_writer_get_type ())
+#define VALA_CCODE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_WRITER, ValaCCodeWriter))
+#define VALA_CCODE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_WRITER, ValaCCodeWriterClass))
+#define VALA_IS_CCODE_WRITER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CCODE_WRITER))
+#define VALA_IS_CCODE_WRITER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_WRITER))
+#define VALA_CCODE_WRITER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_WRITER, ValaCCodeWriterClass))
 
+typedef struct _ValaCCodeWriter ValaCCodeWriter;
+typedef struct _ValaCCodeWriterClass ValaCCodeWriterClass;
+typedef struct _ValaCCodeWriterPrivate ValaCCodeWriterPrivate;
+
+#define VALA_TYPE_CCODE_NODE (vala_ccode_node_get_type ())
+#define VALA_CCODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_NODE, ValaCCodeNode))
+#define VALA_CCODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_NODE, ValaCCodeNodeClass))
+#define VALA_IS_CCODE_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CCODE_NODE))
+#define VALA_IS_CCODE_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_NODE))
+#define VALA_CCODE_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_NODE, ValaCCodeNodeClass))
+
+typedef struct _ValaCCodeNode ValaCCodeNode;
+typedef struct _ValaCCodeNodeClass ValaCCodeNodeClass;
+
+#define VALA_TYPE_CCODE_LINE_DIRECTIVE (vala_ccode_line_directive_get_type ())
+#define VALA_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirective))
+#define VALA_CCODE_LINE_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectiveClass))
+#define VALA_IS_CCODE_LINE_DIRECTIVE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE))
+#define VALA_IS_CCODE_LINE_DIRECTIVE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_LINE_DIRECTIVE))
+#define VALA_CCODE_LINE_DIRECTIVE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_LINE_DIRECTIVE, ValaCCodeLineDirectiveClass))
+
+typedef struct _ValaCCodeLineDirective ValaCCodeLineDirective;
+typedef struct _ValaCCodeLineDirectiveClass ValaCCodeLineDirectiveClass;
+typedef struct _ValaParamSpecCCodeWriter ValaParamSpecCCodeWriter;
+
+/**
+ * Represents a writer to write C source files.
+ */
+struct _ValaCCodeWriter {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaCCodeWriterPrivate * priv;
+};
+
+struct _ValaCCodeWriterClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaCCodeWriter *self);
+};
 
 struct _ValaCCodeWriterPrivate {
 	char* _filename;
@@ -36,16 +82,56 @@ struct _ValaCCodeWriterPrivate {
 	gboolean file_exists;
 	FILE* stream;
 	gint indent;
+	gint current_line_number;
+	gboolean using_line_directive;
 	gboolean _bol;
 };
 
+struct _ValaParamSpecCCodeWriter {
+	GParamSpec parent_instance;
+};
+
+
+
+gpointer vala_ccode_writer_ref (gpointer instance);
+void vala_ccode_writer_unref (gpointer instance);
+GParamSpec* vala_param_spec_ccode_writer (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_ccode_writer (GValue* value, gpointer v_object);
+gpointer vala_value_get_ccode_writer (const GValue* value);
+GType vala_ccode_writer_get_type (void);
 #define VALA_CCODE_WRITER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CCODE_WRITER, ValaCCodeWriterPrivate))
 enum  {
 	VALA_CCODE_WRITER_DUMMY_PROPERTY
 };
+void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value);
+ValaCCodeWriter* vala_ccode_writer_new (const char* filename);
+ValaCCodeWriter* vala_ccode_writer_construct (GType object_type, const char* filename);
+ValaCCodeWriter* vala_ccode_writer_new (const char* filename);
+const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self);
+gboolean vala_ccode_writer_open (ValaCCodeWriter* self);
+void vala_ccode_writer_close (ValaCCodeWriter* self);
+gboolean vala_ccode_writer_get_line_directives (ValaCCodeWriter* self);
+gpointer vala_ccode_node_ref (gpointer instance);
+void vala_ccode_node_unref (gpointer instance);
+GParamSpec* vala_param_spec_ccode_node (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_ccode_node (GValue* value, gpointer v_object);
+gpointer vala_value_get_ccode_node (const GValue* value);
+GType vala_ccode_node_get_type (void);
+void vala_ccode_node_write (ValaCCodeNode* self, ValaCCodeWriter* writer);
+void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s);
+void vala_ccode_writer_write_newline (ValaCCodeWriter* self);
+gboolean vala_ccode_writer_get_bol (ValaCCodeWriter* self);
+GType vala_ccode_line_directive_get_type (void);
+void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line);
+void vala_ccode_writer_write_begin_block (ValaCCodeWriter* self);
+void vala_ccode_writer_write_end_block (ValaCCodeWriter* self);
+void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text);
+void vala_ccode_writer_set_line_directives (ValaCCodeWriter* self, gboolean value);
 static gpointer vala_ccode_writer_parent_class = NULL;
 static void vala_ccode_writer_finalize (ValaCCodeWriter* obj);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
+static gint _vala_array_length (gpointer array);
 
 
 
@@ -73,18 +159,18 @@ gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
 	g_return_val_if_fail (self != NULL, FALSE);
 	self->priv->file_exists = g_file_test (self->priv->_filename, G_FILE_TEST_EXISTS);
 	if (self->priv->file_exists) {
-		char* _tmp0;
-		FILE* _tmp1;
-		_tmp0 = NULL;
-		self->priv->temp_filename = (_tmp0 = g_strdup_printf ("%s.valatmp", self->priv->_filename), self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL), _tmp0);
-		_tmp1 = NULL;
-		self->priv->stream = (_tmp1 = fopen (self->priv->temp_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp1);
+		char* _tmp0_;
+		FILE* _tmp1_;
+		_tmp0_ = NULL;
+		self->priv->temp_filename = (_tmp0_ = g_strdup_printf ("%s.valatmp", self->priv->_filename), self->priv->temp_filename = (g_free (self->priv->temp_filename), NULL), _tmp0_);
+		_tmp1_ = NULL;
+		self->priv->stream = (_tmp1_ = fopen (self->priv->temp_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp1_);
 	} else {
-		FILE* _tmp2;
-		_tmp2 = NULL;
-		self->priv->stream = (_tmp2 = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp2);
+		FILE* _tmp2_;
+		_tmp2_ = NULL;
+		self->priv->stream = (_tmp2_ = fopen (self->priv->_filename, "w"), (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp2_);
 	}
-	return (self->priv->stream != NULL);
+	return self->priv->stream != NULL;
 }
 
 
@@ -92,12 +178,12 @@ gboolean vala_ccode_writer_open (ValaCCodeWriter* self) {
  * Closes the file.
  */
 void vala_ccode_writer_close (ValaCCodeWriter* self) {
-	GError * inner_error;
-	FILE* _tmp0;
+	GError * _inner_error_;
+	FILE* _tmp0_;
 	g_return_if_fail (self != NULL);
-	inner_error = NULL;
-	_tmp0 = NULL;
-	self->priv->stream = (_tmp0 = NULL, (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp0);
+	_inner_error_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->stream = (_tmp0_ = NULL, (self->priv->stream == NULL) ? NULL : (self->priv->stream = (fclose (self->priv->stream), NULL)), _tmp0_);
 	if (self->priv->file_exists) {
 		gboolean changed;
 		changed = TRUE;
@@ -105,19 +191,19 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 			GMappedFile* old_file;
 			GMappedFile* new_file;
 			glong len;
-			GMappedFile* _tmp1;
-			GMappedFile* _tmp2;
-			old_file = g_mapped_file_new (self->priv->_filename, FALSE, &inner_error);
-			if (inner_error != NULL) {
-				if (inner_error->domain == G_FILE_ERROR) {
+			GMappedFile* _tmp1_;
+			GMappedFile* _tmp2_;
+			old_file = g_mapped_file_new (self->priv->_filename, FALSE, &_inner_error_);
+			if (_inner_error_ != NULL) {
+				if (_inner_error_->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
 				}
 				goto __finally0;
 			}
-			new_file = g_mapped_file_new (self->priv->temp_filename, FALSE, &inner_error);
-			if (inner_error != NULL) {
+			new_file = g_mapped_file_new (self->priv->temp_filename, FALSE, &_inner_error_);
+			if (_inner_error_ != NULL) {
 				(old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL));
-				if (inner_error->domain == G_FILE_ERROR) {
+				if (_inner_error_->domain == G_FILE_ERROR) {
 					goto __catch0_g_file_error;
 				}
 				goto __finally0;
@@ -128,10 +214,10 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 					changed = FALSE;
 				}
 			}
-			_tmp1 = NULL;
-			old_file = (_tmp1 = NULL, (old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL)), _tmp1);
-			_tmp2 = NULL;
-			new_file = (_tmp2 = NULL, (new_file == NULL) ? NULL : (new_file = (g_mapped_file_free (new_file), NULL)), _tmp2);
+			_tmp1_ = NULL;
+			old_file = (_tmp1_ = NULL, (old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL)), _tmp1_);
+			_tmp2_ = NULL;
+			new_file = (_tmp2_ = NULL, (new_file == NULL) ? NULL : (new_file = (g_mapped_file_free (new_file), NULL)), _tmp2_);
 			(old_file == NULL) ? NULL : (old_file = (g_mapped_file_free (old_file), NULL));
 			(new_file == NULL) ? NULL : (new_file = (g_mapped_file_free (new_file), NULL));
 		}
@@ -139,16 +225,16 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
 		__catch0_g_file_error:
 		{
 			GError * e;
-			e = inner_error;
-			inner_error = NULL;
+			e = _inner_error_;
+			_inner_error_ = NULL;
 			{
 				(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 			}
 		}
 		__finally0:
-		if (inner_error != NULL) {
-			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-			g_clear_error (&inner_error);
+		if (_inner_error_ != NULL) {
+			g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+			g_clear_error (&_inner_error_);
 			return;
 		}
 		/* assume changed if mmap comparison doesn't work*/
@@ -165,19 +251,28 @@ void vala_ccode_writer_close (ValaCCodeWriter* self) {
  * Writes tabs according to the current indent level.
  */
 void vala_ccode_writer_write_indent (ValaCCodeWriter* self, ValaCCodeLineDirective* line) {
-	gboolean _tmp0;
 	g_return_if_fail (self != NULL);
-	_tmp0 = FALSE;
 	if (self->priv->_line_directives) {
-		_tmp0 = line != NULL;
-	} else {
-		_tmp0 = FALSE;
-	}
-	if (_tmp0) {
-		vala_ccode_node_write ((ValaCCodeNode*) line, self);
+		if (line != NULL) {
+			vala_ccode_node_write ((ValaCCodeNode*) line, self);
+			self->priv->using_line_directive = TRUE;
+		} else {
+			if (self->priv->using_line_directive) {
+				char* _tmp1_;
+				char* _tmp0_;
+				/* no corresponding Vala line, emit line directive for C line*/
+				_tmp1_ = NULL;
+				_tmp0_ = NULL;
+				vala_ccode_writer_write_string (self, _tmp1_ = g_strdup_printf ("#line %d \"%s\"", self->priv->current_line_number + 1, _tmp0_ = g_path_get_basename (self->priv->_filename)));
+				_tmp1_ = (g_free (_tmp1_), NULL);
+				_tmp0_ = (g_free (_tmp0_), NULL);
+				vala_ccode_writer_write_newline (self);
+				self->priv->using_line_directive = FALSE;
+			}
+		}
 	}
 	if (!vala_ccode_writer_get_bol (self)) {
-		fputc ('\n', self->priv->stream);
+		vala_ccode_writer_write_newline (self);
 	}
 	{
 		gint i;
@@ -209,6 +304,7 @@ void vala_ccode_writer_write_string (ValaCCodeWriter* self, const char* s) {
 void vala_ccode_writer_write_newline (ValaCCodeWriter* self) {
 	g_return_if_fail (self != NULL);
 	fputc ('\n', self->priv->stream);
+	self->priv->current_line_number++;
 	self->priv->_bol = TRUE;
 }
 
@@ -248,10 +344,10 @@ void vala_ccode_writer_write_end_block (ValaCCodeWriter* self) {
  */
 void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	gboolean first;
-	char** _tmp1;
+	char** _tmp1_;
 	gint lines_size;
 	gint lines_length1;
-	char** _tmp0;
+	char** _tmp0_;
 	char** lines;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (text != NULL);
@@ -259,9 +355,9 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 	fprintf (self->priv->stream, "/*");
 	first = TRUE;
 	/* separate declaration due to missing memory management in foreach statements */
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	lines = (_tmp1 = _tmp0 = g_strsplit (text, "\n", 0), lines_length1 = g_strv_length (_tmp0), lines_size = lines_length1, _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	lines = (_tmp1_ = _tmp0_ = g_strsplit (text, "\n", 0), lines_length1 = _vala_array_length (_tmp0_), lines_size = lines_length1, _tmp1_);
 	{
 		char** line_collection;
 		int line_collection_length1;
@@ -269,10 +365,10 @@ void vala_ccode_writer_write_comment (ValaCCodeWriter* self, const char* text) {
 		line_collection = lines;
 		line_collection_length1 = lines_length1;
 		for (line_it = 0; line_it < lines_length1; line_it = line_it + 1) {
-			const char* _tmp2;
+			const char* _tmp2_;
 			char* line;
-			_tmp2 = NULL;
-			line = (_tmp2 = line_collection[line_it], (_tmp2 == NULL) ? NULL : g_strdup (_tmp2));
+			_tmp2_ = NULL;
+			line = (_tmp2_ = line_collection[line_it], (_tmp2_ == NULL) ? NULL : g_strdup (_tmp2_));
 			{
 				if (!first) {
 					vala_ccode_writer_write_indent (self, NULL);
@@ -297,12 +393,12 @@ const char* vala_ccode_writer_get_filename (ValaCCodeWriter* self) {
 
 
 void vala_ccode_writer_set_filename (ValaCCodeWriter* self, const char* value) {
-	char* _tmp2;
-	const char* _tmp1;
+	char* _tmp2_;
+	const char* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_filename = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_filename = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), self->priv->_filename = (g_free (self->priv->_filename), NULL), _tmp2_);
 }
 
 
@@ -426,6 +522,7 @@ static void vala_ccode_writer_class_init (ValaCCodeWriterClass * klass) {
 
 static void vala_ccode_writer_instance_init (ValaCCodeWriter * self) {
 	self->priv = VALA_CCODE_WRITER_GET_PRIVATE (self);
+	self->priv->current_line_number = 1;
 	self->priv->_bol = TRUE;
 	self->ref_count = 1;
 }
@@ -470,7 +567,7 @@ void vala_ccode_writer_unref (gpointer instance) {
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		for (i = 0; i < array_length; i = i + 1) {
@@ -479,9 +576,26 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 			}
 		}
 	}
+}
+
+
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	_vala_array_destroy (array, array_length, destroy_func);
 	g_free (array);
 }
 
 
+static gint _vala_array_length (gpointer array) {
+	int length;
+	length = 0;
+	if (array) {
+		while (((gpointer*) array)[length]) {
+			length++;
+		}
+	}
+	return length;
+}
+
+
 
 
