@@ -22,10 +22,65 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <gee/arraylist.h>
+#include <glib.h>
+#include <glib-object.h>
 #include <string.h>
 
 
+#define GEE_TYPE_COLLECTION_OBJECT (gee_collection_object_get_type ())
+#define GEE_COLLECTION_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_COLLECTION_OBJECT, GeeCollectionObject))
+#define GEE_COLLECTION_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_COLLECTION_OBJECT, GeeCollectionObjectClass))
+#define GEE_IS_COLLECTION_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_COLLECTION_OBJECT))
+#define GEE_IS_COLLECTION_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_COLLECTION_OBJECT))
+#define GEE_COLLECTION_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_COLLECTION_OBJECT, GeeCollectionObjectClass))
+
+typedef struct _GeeCollectionObject GeeCollectionObject;
+typedef struct _GeeCollectionObjectClass GeeCollectionObjectClass;
+typedef struct _GeeCollectionObjectPrivate GeeCollectionObjectPrivate;
+
+#define GEE_TYPE_ITERABLE (gee_iterable_get_type ())
+#define GEE_ITERABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_ITERABLE, GeeIterable))
+#define GEE_IS_ITERABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_ITERABLE))
+#define GEE_ITERABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_ITERABLE, GeeIterableIface))
+
+typedef struct _GeeIterable GeeIterable;
+typedef struct _GeeIterableIface GeeIterableIface;
+
+#define GEE_TYPE_ITERATOR (gee_iterator_get_type ())
+#define GEE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_ITERATOR, GeeIterator))
+#define GEE_IS_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_ITERATOR))
+#define GEE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_ITERATOR, GeeIteratorIface))
+
+typedef struct _GeeIterator GeeIterator;
+typedef struct _GeeIteratorIface GeeIteratorIface;
+
+#define GEE_TYPE_COLLECTION (gee_collection_get_type ())
+#define GEE_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_COLLECTION, GeeCollection))
+#define GEE_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_COLLECTION))
+#define GEE_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_COLLECTION, GeeCollectionIface))
+
+typedef struct _GeeCollection GeeCollection;
+typedef struct _GeeCollectionIface GeeCollectionIface;
+
+#define GEE_TYPE_LIST (gee_list_get_type ())
+#define GEE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_LIST, GeeList))
+#define GEE_IS_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_LIST))
+#define GEE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GEE_TYPE_LIST, GeeListIface))
+
+typedef struct _GeeList GeeList;
+typedef struct _GeeListIface GeeListIface;
+
+#define GEE_TYPE_ARRAY_LIST (gee_array_list_get_type ())
+#define GEE_ARRAY_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_TYPE_ARRAY_LIST, GeeArrayList))
+#define GEE_ARRAY_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_TYPE_ARRAY_LIST, GeeArrayListClass))
+#define GEE_IS_ARRAY_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GEE_TYPE_ARRAY_LIST))
+#define GEE_IS_ARRAY_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GEE_TYPE_ARRAY_LIST))
+#define GEE_ARRAY_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GEE_TYPE_ARRAY_LIST, GeeArrayListClass))
+
+typedef struct _GeeArrayList GeeArrayList;
+typedef struct _GeeArrayListClass GeeArrayListClass;
+typedef struct _GeeArrayListPrivate GeeArrayListPrivate;
+
 #define GEE_ARRAY_LIST_TYPE_ITERATOR (gee_array_list_iterator_get_type ())
 #define GEE_ARRAY_LIST_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIterator))
 #define GEE_ARRAY_LIST_ITERATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorClass))
@@ -37,6 +92,89 @@ typedef struct _GeeArrayListIterator GeeArrayListIterator;
 typedef struct _GeeArrayListIteratorClass GeeArrayListIteratorClass;
 typedef struct _GeeArrayListIteratorPrivate GeeArrayListIteratorPrivate;
 
+/**
+ * Base class for all collections.
+ */
+struct _GeeCollectionObject {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	GeeCollectionObjectPrivate * priv;
+};
+
+struct _GeeCollectionObjectClass {
+	GTypeClass parent_class;
+	void (*finalize) (GeeCollectionObject *self);
+};
+
+/**
+ * Implemented by classes that support a simple iteration over instances of the
+ * collection.
+ */
+struct _GeeIteratorIface {
+	GTypeInterface parent_iface;
+	gboolean (*next) (GeeIterator* self);
+	gpointer (*get) (GeeIterator* self);
+};
+
+/**
+ * Implemented by classes that support a simple iteration over instances of the
+ * collection.
+ */
+struct _GeeIterableIface {
+	GTypeInterface parent_iface;
+	GType (*get_element_type) (GeeIterable* self);
+	GeeIterator* (*iterator) (GeeIterable* self);
+};
+
+/**
+ * Serves as the base interface for implementing collection classes. Defines
+ * size, iteration, and modification methods.
+ */
+struct _GeeCollectionIface {
+	GTypeInterface parent_iface;
+	gboolean (*contains) (GeeCollection* self, gconstpointer item);
+	gboolean (*add) (GeeCollection* self, gconstpointer item);
+	gboolean (*remove) (GeeCollection* self, gconstpointer item);
+	void (*clear) (GeeCollection* self);
+	gint (*get_size) (GeeCollection* self);
+};
+
+/**
+ * Represents a collection of items in a well-defined order.
+ */
+struct _GeeListIface {
+	GTypeInterface parent_iface;
+	gpointer (*get) (GeeList* self, gint index);
+	void (*set) (GeeList* self, gint index, gconstpointer item);
+	gint (*index_of) (GeeList* self, gconstpointer item);
+	void (*insert) (GeeList* self, gint index, gconstpointer item);
+	void (*remove_at) (GeeList* self, gint index);
+};
+
+/**
+ * Arrays of arbitrary elements which grow automatically as elements are added.
+ */
+struct _GeeArrayList {
+	GeeCollectionObject parent_instance;
+	GeeArrayListPrivate * priv;
+};
+
+struct _GeeArrayListClass {
+	GeeCollectionObjectClass parent_class;
+};
+
+struct _GeeArrayListPrivate {
+	GType g_type;
+	GBoxedCopyFunc g_dup_func;
+	GDestroyNotify g_destroy_func;
+	gpointer* _items;
+	gint _items_length1;
+	gint _items_size;
+	gint _size;
+	GEqualFunc _equal_func;
+	gint _stamp;
+};
+
 struct _GeeArrayListIterator {
 	GeeCollectionObject parent_instance;
 	GeeArrayListIteratorPrivate * priv;
@@ -47,64 +185,72 @@ struct _GeeArrayListIteratorClass {
 	GeeCollectionObjectClass parent_class;
 };
 
-
-
-struct _GeeArrayListPrivate {
-	gpointer* _items;
-	gint _items_length1;
-	gint _items_size;
-	gint _size;
-	GEqualFunc _equal_func;
-	gint _stamp;
+struct _GeeArrayListIteratorPrivate {
 	GType g_type;
 	GBoxedCopyFunc g_dup_func;
 	GDestroyNotify g_destroy_func;
+	GeeArrayList* _list;
+	gint _index;
 };
 
+
+
+gpointer gee_collection_object_ref (gpointer instance);
+void gee_collection_object_unref (gpointer instance);
+GParamSpec* gee_param_spec_collection_object (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void gee_value_set_collection_object (GValue* value, gpointer v_object);
+gpointer gee_value_get_collection_object (const GValue* value);
+GType gee_collection_object_get_type (void);
+GType gee_iterator_get_type (void);
+GType gee_iterable_get_type (void);
+GType gee_collection_get_type (void);
+GType gee_list_get_type (void);
+GType gee_array_list_get_type (void);
 #define GEE_ARRAY_LIST_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_TYPE_ARRAY_LIST, GeeArrayListPrivate))
 enum  {
 	GEE_ARRAY_LIST_DUMMY_PROPERTY
 };
+void gee_array_list_set_equal_func (GeeArrayList* self, GEqualFunc value);
+GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
+GeeArrayList* gee_array_list_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
+GeeArrayList* gee_array_list_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GEqualFunc equal_func);
 static GType gee_array_list_real_get_element_type (GeeIterable* base);
+static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
+static GeeArrayListIterator* gee_array_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
+static GType gee_array_list_iterator_get_type (void);
 static GeeIterator* gee_array_list_real_iterator (GeeIterable* base);
+gint gee_list_index_of (GeeList* self, gconstpointer item);
 static gboolean gee_array_list_real_contains (GeeCollection* base, gconstpointer item);
 static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item);
 static gpointer gee_array_list_real_get (GeeList* base, gint index);
 static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer item);
+static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count);
 static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item);
+static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta);
 static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer item);
+void gee_list_remove_at (GeeList* self, gint index);
 static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer item);
 static void gee_array_list_real_remove_at (GeeList* base, gint index);
 static void gee_array_list_real_clear (GeeCollection* base);
-static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta);
-static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count);
 static void gee_array_list_set_capacity (GeeArrayList* self, gint value);
-struct _GeeArrayListIteratorPrivate {
-	GeeArrayList* _list;
-	gint _index;
-	GType g_type;
-	GBoxedCopyFunc g_dup_func;
-	GDestroyNotify g_destroy_func;
-};
-
 #define GEE_ARRAY_LIST_ITERATOR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GEE_ARRAY_LIST_TYPE_ITERATOR, GeeArrayListIteratorPrivate))
 enum  {
 	GEE_ARRAY_LIST_ITERATOR_DUMMY_PROPERTY
 };
-static GeeArrayListIterator* gee_array_list_iterator_construct (GType object_type, GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
+static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value);
 static GeeArrayListIterator* gee_array_list_iterator_new (GType g_type, GBoxedCopyFunc g_dup_func, GDestroyNotify g_destroy_func, GeeArrayList* list);
 static gboolean gee_array_list_iterator_real_next (GeeIterator* base);
+gpointer gee_list_get (GeeList* self, gint index);
 static gpointer gee_array_list_iterator_real_get (GeeIterator* base);
-static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value);
 static gpointer gee_array_list_iterator_parent_class = NULL;
 static GeeIteratorIface* gee_array_list_iterator_gee_iterator_parent_iface = NULL;
 static void gee_array_list_iterator_finalize (GeeCollectionObject* obj);
-static GType gee_array_list_iterator_get_type (void);
 static gpointer gee_array_list_parent_class = NULL;
 static GeeIterableIface* gee_array_list_gee_iterable_parent_iface = NULL;
 static GeeCollectionIface* gee_array_list_gee_collection_parent_iface = NULL;
 static GeeListIface* gee_array_list_gee_list_parent_iface = NULL;
 static void gee_array_list_finalize (GeeCollectionObject* obj);
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
 static void _vala_array_move (gpointer array, gsize element_size, gint src, gint dest, gint length);
 
@@ -165,53 +311,53 @@ static gint gee_array_list_real_index_of (GeeList* base, gconstpointer item) {
 
 static gpointer gee_array_list_real_get (GeeList* base, gint index) {
 	GeeArrayList * self;
-	gboolean _tmp0;
-	gconstpointer _tmp1;
+	gboolean _tmp0_;
+	gconstpointer _tmp1_;
 	self = (GeeArrayList*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (index >= 0) {
-		_tmp0 = index < self->priv->_size;
+		_tmp0_ = index < self->priv->_size;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	g_assert (_tmp0);
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->_items[index], ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1));
+	g_assert (_tmp0_);
+	_tmp1_ = NULL;
+	return (_tmp1_ = self->priv->_items[index], ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_));
 }
 
 
 static void gee_array_list_real_set (GeeList* base, gint index, gconstpointer item) {
 	GeeArrayList * self;
-	gboolean _tmp0;
-	gpointer _tmp2;
-	gconstpointer _tmp1;
+	gboolean _tmp0_;
+	gpointer _tmp2_;
+	gconstpointer _tmp1_;
 	self = (GeeArrayList*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (index >= 0) {
-		_tmp0 = index < self->priv->_size;
+		_tmp0_ = index < self->priv->_size;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	g_assert (_tmp0);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_items[index] = (_tmp2 = (_tmp1 = item, ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2);
+	g_assert (_tmp0_);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_items[index] = (_tmp2_ = (_tmp1_ = item, ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2_);
 }
 
 
 static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item) {
 	GeeArrayList * self;
-	gint _tmp2;
-	gpointer _tmp1;
-	gconstpointer _tmp0;
+	gpointer _tmp2_;
+	gpointer *_tmp1_;
+	gconstpointer _tmp0_;
 	self = (GeeArrayList*) base;
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	_tmp2 = self->priv->_size++;
-	self->priv->_items[_tmp2] = (_tmp1 = (_tmp0 = item, ((_tmp0 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0) : self->priv->g_dup_func ((gpointer) _tmp0)), ((self->priv->_items[_tmp2] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[_tmp2] = (self->priv->g_destroy_func (self->priv->_items[_tmp2]), NULL)), _tmp1);
+	_tmp2_ = NULL;
+	_tmp0_ = NULL;
+	_tmp1_ = &self->priv->_items[self->priv->_size++];
+	(*_tmp1_) = (_tmp2_ = (_tmp0_ = item, ((_tmp0_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp0_) : self->priv->g_dup_func ((gpointer) _tmp0_)), (((*_tmp1_) == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : ((*_tmp1_) = (self->priv->g_destroy_func ((*_tmp1_)), NULL)), _tmp2_);
 	self->priv->_stamp++;
 	return TRUE;
 }
@@ -219,24 +365,24 @@ static gboolean gee_array_list_real_add (GeeCollection* base, gconstpointer item
 
 static void gee_array_list_real_insert (GeeList* base, gint index, gconstpointer item) {
 	GeeArrayList * self;
-	gboolean _tmp0;
-	gpointer _tmp2;
-	gconstpointer _tmp1;
+	gboolean _tmp0_;
+	gpointer _tmp2_;
+	gconstpointer _tmp1_;
 	self = (GeeArrayList*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (index >= 0) {
-		_tmp0 = index <= self->priv->_size;
+		_tmp0_ = index <= self->priv->_size;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	g_assert (_tmp0);
+	g_assert (_tmp0_);
 	if (self->priv->_size == self->priv->_items_length1) {
 		gee_array_list_grow_if_needed (self, 1);
 	}
 	gee_array_list_shift (self, index, 1);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_items[index] = (_tmp2 = (_tmp1 = item, ((_tmp1 == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1) : self->priv->g_dup_func ((gpointer) _tmp1)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_items[index] = (_tmp2_ = (_tmp1_ = item, ((_tmp1_ == NULL) || (self->priv->g_dup_func == NULL)) ? ((gpointer) _tmp1_) : self->priv->g_dup_func ((gpointer) _tmp1_)), ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp2_);
 	self->priv->_stamp++;
 }
 
@@ -260,18 +406,18 @@ static gboolean gee_array_list_real_remove (GeeCollection* base, gconstpointer i
 
 static void gee_array_list_real_remove_at (GeeList* base, gint index) {
 	GeeArrayList * self;
-	gboolean _tmp0;
-	gpointer _tmp1;
+	gboolean _tmp0_;
+	gpointer _tmp1_;
 	self = (GeeArrayList*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (index >= 0) {
-		_tmp0 = index < self->priv->_size;
+		_tmp0_ = index < self->priv->_size;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	g_assert (_tmp0);
-	_tmp1 = NULL;
-	self->priv->_items[index] = (_tmp1 = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp1);
+	g_assert (_tmp0_);
+	_tmp1_ = NULL;
+	self->priv->_items[index] = (_tmp1_ = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp1_);
 	gee_array_list_shift (self, index + 1, -1);
 	self->priv->_stamp++;
 }
@@ -284,9 +430,9 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 		gint index;
 		index = 0;
 		for (; index < self->priv->_size; index++) {
-			gpointer _tmp0;
-			_tmp0 = NULL;
-			self->priv->_items[index] = (_tmp0 = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp0);
+			gpointer _tmp0_;
+			_tmp0_ = NULL;
+			self->priv->_items[index] = (_tmp0_ = NULL, ((self->priv->_items[index] == NULL) || (self->priv->g_destroy_func == NULL)) ? NULL : (self->priv->_items[index] = (self->priv->g_destroy_func (self->priv->_items[index]), NULL)), _tmp0_);
 		}
 	}
 	self->priv->_size = 0;
@@ -295,22 +441,22 @@ static void gee_array_list_real_clear (GeeCollection* base) {
 
 
 static void gee_array_list_shift (GeeArrayList* self, gint start, gint delta) {
-	gboolean _tmp0;
-	gboolean _tmp1;
+	gboolean _tmp0_;
+	gboolean _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp0 = FALSE;
-	_tmp1 = FALSE;
+	_tmp0_ = FALSE;
+	_tmp1_ = FALSE;
 	if (start >= 0) {
-		_tmp1 = start <= self->priv->_size;
+		_tmp1_ = start <= self->priv->_size;
 	} else {
-		_tmp1 = FALSE;
+		_tmp1_ = FALSE;
 	}
-	if (_tmp1) {
-		_tmp0 = start >= (-delta);
+	if (_tmp1_) {
+		_tmp0_ = start >= (-delta);
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	g_assert (_tmp0);
+	g_assert (_tmp0_);
 	_vala_array_move (self->priv->_items, sizeof (gpointer), start, start + delta, self->priv->_size - start);
 	self->priv->_size = self->priv->_size + delta;
 }
@@ -322,27 +468,27 @@ static void gee_array_list_grow_if_needed (GeeArrayList* self, gint new_count) {
 	g_assert (new_count >= 0);
 	minimum_size = self->priv->_size + new_count;
 	if (minimum_size > self->priv->_items_length1) {
-		gint _tmp0;
-		_tmp0 = 0;
+		gint _tmp0_;
+		_tmp0_ = 0;
 		if (new_count > self->priv->_items_length1) {
-			_tmp0 = minimum_size;
+			_tmp0_ = minimum_size;
 		} else {
-			_tmp0 = 2 * self->priv->_items_length1;
+			_tmp0_ = 2 * self->priv->_items_length1;
 		}
 		/* double the capacity unless we add even more items at this time*/
-		gee_array_list_set_capacity (self, _tmp0);
+		gee_array_list_set_capacity (self, _tmp0_);
 	}
 }
 
 
 static void gee_array_list_set_capacity (GeeArrayList* self, gint value) {
-	gint _tmp0;
+	gint _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_assert (value >= self->priv->_size);
-	_tmp0 = value;
+	_tmp0_ = value;
 	self->priv->_items = g_renew (gpointer, self->priv->_items, value);
-	(_tmp0 > self->priv->_items_length1) ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0 - self->priv->_items_length1)) : NULL;
-	self->priv->_items_length1 = _tmp0;
+	(_tmp0_ > self->priv->_items_length1) ? memset (self->priv->_items + self->priv->_items_length1, 0, sizeof (gpointer) * (_tmp0_ - self->priv->_items_length1)) : NULL;
+	self->priv->_items_length1 = _tmp0_;
 }
 
 
@@ -389,16 +535,16 @@ static gboolean gee_array_list_iterator_real_next (GeeIterator* base) {
 
 static gpointer gee_array_list_iterator_real_get (GeeIterator* base) {
 	GeeArrayListIterator * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (GeeArrayListIterator*) base;
 	g_assert (self->_stamp == self->priv->_list->priv->_stamp);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (self->priv->_index < 0) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp0 = self->priv->_index >= self->priv->_list->priv->_size;
+		_tmp0_ = self->priv->_index >= self->priv->_list->priv->_size;
 	}
-	if (_tmp0) {
+	if (_tmp0_) {
 		return NULL;
 	}
 	return gee_list_get ((GeeList*) self->priv->_list, self->priv->_index);
@@ -406,12 +552,12 @@ static gpointer gee_array_list_iterator_real_get (GeeIterator* base) {
 
 
 static void gee_array_list_iterator_set_list (GeeArrayListIterator* self, GeeArrayList* value) {
-	GeeArrayList* _tmp1;
-	GeeArrayList* _tmp0;
+	GeeArrayList* _tmp1_;
+	GeeArrayList* _tmp0_;
 	g_return_if_fail (self != NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->_list = (_tmp1 = (_tmp0 = value, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)), _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->_list = (_tmp1_ = (_tmp0_ = value, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_)), (self->priv->_list == NULL) ? NULL : (self->priv->_list = (gee_collection_object_unref (self->priv->_list), NULL)), _tmp1_);
 	self->_stamp = self->priv->_list->priv->_stamp;
 }
 
@@ -523,7 +669,7 @@ GType gee_array_list_get_type (void) {
 }
 
 
-static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
 	if ((array != NULL) && (destroy_func != NULL)) {
 		int i;
 		for (i = 0; i < array_length; i = i + 1) {
@@ -532,6 +678,11 @@ static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify
 			}
 		}
 	}
+}
+
+
+static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
+	_vala_array_destroy (array, array_length, destroy_func);
 	g_free (array);
 }
 
