@@ -20,23 +20,63 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <gobject/valaccodecompiler.h>
-#include <vala/valareport.h>
-#include <vala/valasourcereference.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <gee/list.h>
-#include <vala/valasourcefile.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <stdlib.h>
+#include <string.h>
+#include <vala.h>
+#include <gee.h>
+#include <stdio.h>
 #include <glib/gstdio.h>
 #include <gobject/gvaluecollector.h>
 
 
+#define VALA_TYPE_CCODE_COMPILER (vala_ccode_compiler_get_type ())
+#define VALA_CCODE_COMPILER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CCODE_COMPILER, ValaCCodeCompiler))
+#define VALA_CCODE_COMPILER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CCODE_COMPILER, ValaCCodeCompilerClass))
+#define VALA_IS_CCODE_COMPILER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CCODE_COMPILER))
+#define VALA_IS_CCODE_COMPILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CCODE_COMPILER))
+#define VALA_CCODE_COMPILER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CCODE_COMPILER, ValaCCodeCompilerClass))
+
+typedef struct _ValaCCodeCompiler ValaCCodeCompiler;
+typedef struct _ValaCCodeCompilerClass ValaCCodeCompilerClass;
+typedef struct _ValaCCodeCompilerPrivate ValaCCodeCompilerPrivate;
+typedef struct _ValaParamSpecCCodeCompiler ValaParamSpecCCodeCompiler;
+
+/**
+ * Interface to the C compiler.
+ */
+struct _ValaCCodeCompiler {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaCCodeCompilerPrivate * priv;
+};
+
+struct _ValaCCodeCompilerClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaCCodeCompiler *self);
+};
+
+struct _ValaParamSpecCCodeCompiler {
+	GParamSpec parent_instance;
+};
 
 
+
+gpointer vala_ccode_compiler_ref (gpointer instance);
+void vala_ccode_compiler_unref (gpointer instance);
+GParamSpec* vala_param_spec_ccode_compiler (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_ccode_compiler (GValue* value, gpointer v_object);
+gpointer vala_value_get_ccode_compiler (const GValue* value);
+GType vala_ccode_compiler_get_type (void);
 enum  {
 	VALA_CCODE_COMPILER_DUMMY_PROPERTY
 };
+ValaCCodeCompiler* vala_ccode_compiler_new (void);
+ValaCCodeCompiler* vala_ccode_compiler_construct (GType object_type);
+ValaCCodeCompiler* vala_ccode_compiler_new (void);
 static gboolean vala_ccode_compiler_package_exists (const char* package_name);
+void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context, const char* cc_command, char** cc_options, int cc_options_length1);
 static gpointer vala_ccode_compiler_parent_class = NULL;
 static void vala_ccode_compiler_finalize (ValaCCodeCompiler* obj);
 static int _vala_strcmp0 (const char * str1, const char * str2);
@@ -56,41 +96,41 @@ ValaCCodeCompiler* vala_ccode_compiler_new (void) {
 
 
 static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
-	GError * inner_error;
+	GError * _inner_error_;
 	char* pc;
 	gint exit_status;
 	g_return_val_if_fail (package_name != NULL, FALSE);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	pc = g_strconcat ("pkg-config --exists ", package_name, NULL);
 	exit_status = 0;
 	{
-		gboolean _tmp0;
-		g_spawn_command_line_sync (pc, NULL, NULL, &exit_status, &inner_error);
-		if (inner_error != NULL) {
-			if (inner_error->domain == G_SPAWN_ERROR) {
+		gboolean _tmp0_;
+		g_spawn_command_line_sync (pc, NULL, NULL, &exit_status, &_inner_error_);
+		if (_inner_error_ != NULL) {
+			if (_inner_error_->domain == G_SPAWN_ERROR) {
 				goto __catch0_g_spawn_error;
 			}
 			goto __finally0;
 		}
-		return (_tmp0 = 0 == exit_status, pc = (g_free (pc), NULL), _tmp0);
+		return (_tmp0_ = 0 == exit_status, pc = (g_free (pc), NULL), _tmp0_);
 	}
 	goto __finally0;
 	__catch0_g_spawn_error:
 	{
 		GError * e;
-		e = inner_error;
-		inner_error = NULL;
+		e = _inner_error_;
+		_inner_error_ = NULL;
 		{
-			gboolean _tmp1;
+			gboolean _tmp1_;
 			vala_report_error (NULL, e->message);
-			return (_tmp1 = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), pc = (g_free (pc), NULL), _tmp1);
+			return (_tmp1_ = FALSE, (e == NULL) ? NULL : (e = (g_error_free (e), NULL)), pc = (g_free (pc), NULL), _tmp1_);
 		}
 	}
 	__finally0:
-	if (inner_error != NULL) {
+	if (_inner_error_ != NULL) {
 		pc = (g_free (pc), NULL);
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-		g_clear_error (&inner_error);
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
 		return FALSE;
 	}
 	pc = (g_free (pc), NULL);
@@ -104,52 +144,50 @@ static gboolean vala_ccode_compiler_package_exists (const char* package_name) {
  * @param context a code context
  */
 void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* context, const char* cc_command, char** cc_options, int cc_options_length1) {
-	GError * inner_error;
+	GError * _inner_error_;
 	char* pc;
-	char* _tmp1;
+	char* _tmp1_;
 	char* pkgflags;
 	gint exit_status;
-	const char* _tmp11;
+	const char* _tmp11_;
 	char* cmdline;
-	gboolean _tmp21;
-	gboolean _tmp22;
 	GeeList* source_files;
 	GeeList* c_source_files;
-	char* _tmp34;
-	char* _tmp33;
+	char* _tmp29_;
+	char* _tmp28_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (context != NULL);
-	inner_error = NULL;
+	_inner_error_ = NULL;
 	pc = g_strdup ("pkg-config --cflags");
 	if (!vala_code_context_get_compile_only (context)) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		pc = (_tmp0 = g_strconcat (pc, " --libs", NULL), pc = (g_free (pc), NULL), _tmp0);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		pc = (_tmp0_ = g_strconcat (pc, " --libs", NULL), pc = (g_free (pc), NULL), _tmp0_);
 	}
-	_tmp1 = NULL;
-	pc = (_tmp1 = g_strconcat (pc, " gobject-2.0", NULL), pc = (g_free (pc), NULL), _tmp1);
+	_tmp1_ = NULL;
+	pc = (_tmp1_ = g_strconcat (pc, " gobject-2.0", NULL), pc = (g_free (pc), NULL), _tmp1_);
 	if (vala_code_context_get_thread (context)) {
-		char* _tmp2;
-		_tmp2 = NULL;
-		pc = (_tmp2 = g_strconcat (pc, " gthread-2.0", NULL), pc = (g_free (pc), NULL), _tmp2);
+		char* _tmp2_;
+		_tmp2_ = NULL;
+		pc = (_tmp2_ = g_strconcat (pc, " gthread-2.0", NULL), pc = (g_free (pc), NULL), _tmp2_);
 	}
 	{
-		GeeList* _tmp3;
-		GeeIterator* _tmp4;
+		GeeList* _tmp3_;
+		GeeIterator* _tmp4_;
 		GeeIterator* _pkg_it;
-		_tmp3 = NULL;
-		_tmp4 = NULL;
-		_pkg_it = (_tmp4 = gee_iterable_iterator ((GeeIterable*) (_tmp3 = vala_code_context_get_packages (context))), (_tmp3 == NULL) ? NULL : (_tmp3 = (gee_collection_object_unref (_tmp3), NULL)), _tmp4);
+		_tmp3_ = NULL;
+		_tmp4_ = NULL;
+		_pkg_it = (_tmp4_ = gee_iterable_iterator ((GeeIterable*) (_tmp3_ = vala_code_context_get_packages (context))), (_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL)), _tmp4_);
 		while (gee_iterator_next (_pkg_it)) {
 			char* pkg;
 			pkg = (char*) gee_iterator_get (_pkg_it);
 			if (vala_ccode_compiler_package_exists (pkg)) {
-				char* _tmp6;
-				char* _tmp5;
-				_tmp6 = NULL;
-				_tmp5 = NULL;
-				pc = (_tmp6 = g_strconcat (pc, _tmp5 = g_strconcat (" ", pkg, NULL), NULL), pc = (g_free (pc), NULL), _tmp6);
-				_tmp5 = (g_free (_tmp5), NULL);
+				char* _tmp6_;
+				char* _tmp5_;
+				_tmp6_ = NULL;
+				_tmp5_ = NULL;
+				pc = (_tmp6_ = g_strconcat (pc, _tmp5_ = g_strconcat (" ", pkg, NULL), NULL), pc = (g_free (pc), NULL), _tmp6_);
+				_tmp5_ = (g_free (_tmp5_), NULL);
 			}
 			pkg = (g_free (pkg), NULL);
 		}
@@ -158,25 +196,25 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	pkgflags = NULL;
 	exit_status = 0;
 	{
-		char* _tmp9;
-		gboolean _tmp8;
-		char* _tmp7;
-		_tmp9 = NULL;
-		_tmp7 = NULL;
-		_tmp8 = g_spawn_command_line_sync (pc, &_tmp7, NULL, &exit_status, &inner_error);
-		pkgflags = (_tmp9 = _tmp7, pkgflags = (g_free (pkgflags), NULL), _tmp9);
-		_tmp8;
-		if (inner_error != NULL) {
-			if (inner_error->domain == G_SPAWN_ERROR) {
+		char* _tmp9_;
+		gboolean _tmp8_;
+		char* _tmp7_;
+		_tmp9_ = NULL;
+		_tmp7_ = NULL;
+		_tmp8_ = g_spawn_command_line_sync (pc, &_tmp7_, NULL, &exit_status, &_inner_error_);
+		pkgflags = (_tmp9_ = _tmp7_, pkgflags = (g_free (pkgflags), NULL), _tmp9_);
+		_tmp8_;
+		if (_inner_error_ != NULL) {
+			if (_inner_error_->domain == G_SPAWN_ERROR) {
 				goto __catch1_g_spawn_error;
 			}
 			goto __finally1;
 		}
 		if (exit_status != 0) {
-			char* _tmp10;
-			_tmp10 = NULL;
-			vala_report_error (NULL, _tmp10 = g_strdup_printf ("pkg-config exited with status %d", exit_status));
-			_tmp10 = (g_free (_tmp10), NULL);
+			char* _tmp10_;
+			_tmp10_ = NULL;
+			vala_report_error (NULL, _tmp10_ = g_strdup_printf ("pkg-config exited with status %d", exit_status));
+			_tmp10_ = (g_free (_tmp10_), NULL);
 			pc = (g_free (pc), NULL);
 			pkgflags = (g_free (pkgflags), NULL);
 			return;
@@ -186,8 +224,8 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 	__catch1_g_spawn_error:
 	{
 		GError * e;
-		e = inner_error;
-		inner_error = NULL;
+		e = _inner_error_;
+		_inner_error_ = NULL;
 		{
 			vala_report_error (NULL, e->message);
 			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
@@ -197,89 +235,65 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		}
 	}
 	__finally1:
-	if (inner_error != NULL) {
+	if (_inner_error_ != NULL) {
 		pc = (g_free (pc), NULL);
 		pkgflags = (g_free (pkgflags), NULL);
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-		g_clear_error (&inner_error);
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
 		return;
 	}
 	/* TODO compile the C code files in parallel*/
 	if (cc_command == NULL) {
 		cc_command = "cc";
 	}
-	_tmp11 = NULL;
-	cmdline = (_tmp11 = cc_command, (_tmp11 == NULL) ? NULL : g_strdup (_tmp11));
+	_tmp11_ = NULL;
+	cmdline = (_tmp11_ = cc_command, (_tmp11_ == NULL) ? NULL : g_strdup (_tmp11_));
 	if (vala_code_context_get_debug (context)) {
-		char* _tmp12;
-		_tmp12 = NULL;
-		cmdline = (_tmp12 = g_strconcat (cmdline, " -g", NULL), cmdline = (g_free (cmdline), NULL), _tmp12);
+		char* _tmp12_;
+		_tmp12_ = NULL;
+		cmdline = (_tmp12_ = g_strconcat (cmdline, " -g", NULL), cmdline = (g_free (cmdline), NULL), _tmp12_);
 	}
 	if (vala_code_context_get_compile_only (context)) {
-		char* _tmp13;
-		_tmp13 = NULL;
-		cmdline = (_tmp13 = g_strconcat (cmdline, " -c", NULL), cmdline = (g_free (cmdline), NULL), _tmp13);
+		char* _tmp13_;
+		_tmp13_ = NULL;
+		cmdline = (_tmp13_ = g_strconcat (cmdline, " -c", NULL), cmdline = (g_free (cmdline), NULL), _tmp13_);
 	} else {
 		if (vala_code_context_get_output (context) != NULL) {
-			const char* _tmp14;
+			const char* _tmp14_;
 			char* output;
-			gboolean _tmp15;
-			gboolean _tmp16;
-			char* _tmp20;
-			char* _tmp19;
-			char* _tmp18;
-			_tmp14 = NULL;
-			output = (_tmp14 = vala_code_context_get_output (context), (_tmp14 == NULL) ? NULL : g_strdup (_tmp14));
-			_tmp15 = FALSE;
-			_tmp16 = FALSE;
+			gboolean _tmp15_;
+			gboolean _tmp16_;
+			char* _tmp20_;
+			char* _tmp19_;
+			char* _tmp18_;
+			_tmp14_ = NULL;
+			output = (_tmp14_ = vala_code_context_get_output (context), (_tmp14_ == NULL) ? NULL : g_strdup (_tmp14_));
+			_tmp15_ = FALSE;
+			_tmp16_ = FALSE;
 			if (vala_code_context_get_directory (context) != NULL) {
-				_tmp16 = _vala_strcmp0 (vala_code_context_get_directory (context), "") != 0;
+				_tmp16_ = _vala_strcmp0 (vala_code_context_get_directory (context), "") != 0;
 			} else {
-				_tmp16 = FALSE;
+				_tmp16_ = FALSE;
 			}
-			if (_tmp16) {
-				_tmp15 = !g_path_is_absolute (vala_code_context_get_output (context));
+			if (_tmp16_) {
+				_tmp15_ = !g_path_is_absolute (vala_code_context_get_output (context));
 			} else {
-				_tmp15 = FALSE;
+				_tmp15_ = FALSE;
 			}
-			if (_tmp15) {
-				char* _tmp17;
-				_tmp17 = NULL;
-				output = (_tmp17 = g_strdup_printf ("%s%c%s", vala_code_context_get_directory (context), (gint) G_DIR_SEPARATOR, vala_code_context_get_output (context)), output = (g_free (output), NULL), _tmp17);
+			if (_tmp15_) {
+				char* _tmp17_;
+				_tmp17_ = NULL;
+				output = (_tmp17_ = g_strdup_printf ("%s%c%s", vala_code_context_get_directory (context), (gint) G_DIR_SEPARATOR, vala_code_context_get_output (context)), output = (g_free (output), NULL), _tmp17_);
 			}
-			_tmp20 = NULL;
-			_tmp19 = NULL;
-			_tmp18 = NULL;
-			cmdline = (_tmp20 = g_strconcat (cmdline, _tmp19 = g_strconcat (" -o ", _tmp18 = g_shell_quote (output), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp20);
-			_tmp19 = (g_free (_tmp19), NULL);
-			_tmp18 = (g_free (_tmp18), NULL);
+			_tmp20_ = NULL;
+			_tmp19_ = NULL;
+			_tmp18_ = NULL;
+			cmdline = (_tmp20_ = g_strconcat (cmdline, _tmp19_ = g_strconcat (" -o ", _tmp18_ = g_shell_quote (output), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp20_);
+			_tmp19_ = (g_free (_tmp19_), NULL);
+			_tmp18_ = (g_free (_tmp18_), NULL);
 			output = (g_free (output), NULL);
 		}
 	}
-	_tmp21 = FALSE;
-	_tmp22 = FALSE;
-	if (vala_code_context_get_legacy_headers (context)) {
-		_tmp22 = vala_code_context_get_directory (context) != NULL;
-	} else {
-		_tmp22 = FALSE;
-	}
-	if (_tmp22) {
-		_tmp21 = _vala_strcmp0 (vala_code_context_get_directory (context), "") != 0;
-	} else {
-		_tmp21 = FALSE;
-	}
-	/* make sure include files can be found if -d is used */
-	if (_tmp21) {
-		char* _tmp25;
-		char* _tmp24;
-		char* _tmp23;
-		_tmp25 = NULL;
-		_tmp24 = NULL;
-		_tmp23 = NULL;
-		cmdline = (_tmp25 = g_strconcat (cmdline, _tmp24 = g_strconcat (" -I", _tmp23 = g_shell_quote (vala_code_context_get_directory (context)), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp25);
-		_tmp24 = (g_free (_tmp24), NULL);
-		_tmp23 = (g_free (_tmp23), NULL);
-	}
 	/* we're only interested in non-pkg source files */
 	source_files = vala_code_context_get_source_files (context);
 	{
@@ -289,18 +303,18 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			ValaSourceFile* file;
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			if (!vala_source_file_get_external_package (file)) {
-				char* _tmp29;
-				char* _tmp28;
-				char* _tmp27;
-				char* _tmp26;
-				_tmp29 = NULL;
-				_tmp28 = NULL;
-				_tmp27 = NULL;
-				_tmp26 = NULL;
-				cmdline = (_tmp29 = g_strconcat (cmdline, _tmp28 = g_strconcat (" ", _tmp27 = g_shell_quote (_tmp26 = vala_source_file_get_csource_filename (file)), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp29);
-				_tmp28 = (g_free (_tmp28), NULL);
-				_tmp27 = (g_free (_tmp27), NULL);
-				_tmp26 = (g_free (_tmp26), NULL);
+				char* _tmp24_;
+				char* _tmp23_;
+				char* _tmp22_;
+				char* _tmp21_;
+				_tmp24_ = NULL;
+				_tmp23_ = NULL;
+				_tmp22_ = NULL;
+				_tmp21_ = NULL;
+				cmdline = (_tmp24_ = g_strconcat (cmdline, _tmp23_ = g_strconcat (" ", _tmp22_ = g_shell_quote (_tmp21_ = vala_source_file_get_csource_filename (file)), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp24_);
+				_tmp23_ = (g_free (_tmp23_), NULL);
+				_tmp22_ = (g_free (_tmp22_), NULL);
+				_tmp21_ = (g_free (_tmp21_), NULL);
 			}
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
 		}
@@ -312,26 +326,26 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		_file_it = gee_iterable_iterator ((GeeIterable*) c_source_files);
 		while (gee_iterator_next (_file_it)) {
 			char* file;
-			char* _tmp32;
-			char* _tmp31;
-			char* _tmp30;
+			char* _tmp27_;
+			char* _tmp26_;
+			char* _tmp25_;
 			file = (char*) gee_iterator_get (_file_it);
-			_tmp32 = NULL;
-			_tmp31 = NULL;
-			_tmp30 = NULL;
-			cmdline = (_tmp32 = g_strconcat (cmdline, _tmp31 = g_strconcat (" ", _tmp30 = g_shell_quote (file), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp32);
-			_tmp31 = (g_free (_tmp31), NULL);
-			_tmp30 = (g_free (_tmp30), NULL);
+			_tmp27_ = NULL;
+			_tmp26_ = NULL;
+			_tmp25_ = NULL;
+			cmdline = (_tmp27_ = g_strconcat (cmdline, _tmp26_ = g_strconcat (" ", _tmp25_ = g_shell_quote (file), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp27_);
+			_tmp26_ = (g_free (_tmp26_), NULL);
+			_tmp25_ = (g_free (_tmp25_), NULL);
 			file = (g_free (file), NULL);
 		}
 		(_file_it == NULL) ? NULL : (_file_it = (gee_collection_object_unref (_file_it), NULL));
 	}
 	/* add libraries after source files to fix linking
 	 with --as-needed and on Windows*/
-	_tmp34 = NULL;
-	_tmp33 = NULL;
-	cmdline = (_tmp34 = g_strconcat (cmdline, _tmp33 = g_strconcat (" ", g_strstrip (pkgflags), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp34);
-	_tmp33 = (g_free (_tmp33), NULL);
+	_tmp29_ = NULL;
+	_tmp28_ = NULL;
+	cmdline = (_tmp29_ = g_strconcat (cmdline, _tmp28_ = g_strconcat (" ", g_strstrip (pkgflags), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp29_);
+	_tmp28_ = (g_free (_tmp28_), NULL);
 	{
 		char** cc_option_collection;
 		int cc_option_collection_length1;
@@ -339,59 +353,62 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 		cc_option_collection = cc_options;
 		cc_option_collection_length1 = cc_options_length1;
 		for (cc_option_it = 0; cc_option_it < cc_options_length1; cc_option_it = cc_option_it + 1) {
-			const char* _tmp38;
+			const char* _tmp33_;
 			char* cc_option;
-			_tmp38 = NULL;
-			cc_option = (_tmp38 = cc_option_collection[cc_option_it], (_tmp38 == NULL) ? NULL : g_strdup (_tmp38));
+			_tmp33_ = NULL;
+			cc_option = (_tmp33_ = cc_option_collection[cc_option_it], (_tmp33_ == NULL) ? NULL : g_strdup (_tmp33_));
 			{
-				char* _tmp37;
-				char* _tmp36;
-				char* _tmp35;
-				_tmp37 = NULL;
-				_tmp36 = NULL;
-				_tmp35 = NULL;
-				cmdline = (_tmp37 = g_strconcat (cmdline, _tmp36 = g_strconcat (" ", _tmp35 = g_shell_quote (cc_option), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp37);
-				_tmp36 = (g_free (_tmp36), NULL);
-				_tmp35 = (g_free (_tmp35), NULL);
+				char* _tmp32_;
+				char* _tmp31_;
+				char* _tmp30_;
+				_tmp32_ = NULL;
+				_tmp31_ = NULL;
+				_tmp30_ = NULL;
+				cmdline = (_tmp32_ = g_strconcat (cmdline, _tmp31_ = g_strconcat (" ", _tmp30_ = g_shell_quote (cc_option), NULL), NULL), cmdline = (g_free (cmdline), NULL), _tmp32_);
+				_tmp31_ = (g_free (_tmp31_), NULL);
+				_tmp30_ = (g_free (_tmp30_), NULL);
 				cc_option = (g_free (cc_option), NULL);
 			}
 		}
 	}
+	if (vala_code_context_get_verbose_mode (context)) {
+		fprintf (stdout, "%s\n", cmdline);
+	}
 	{
-		g_spawn_command_line_sync (cmdline, NULL, NULL, &exit_status, &inner_error);
-		if (inner_error != NULL) {
-			if (inner_error->domain == G_SPAWN_ERROR) {
+		g_spawn_command_line_sync (cmdline, NULL, NULL, &exit_status, &_inner_error_);
+		if (_inner_error_ != NULL) {
+			if (_inner_error_->domain == G_SPAWN_ERROR) {
 				goto __catch2_g_spawn_error;
 			}
 			goto __finally2;
 		}
 		if (exit_status != 0) {
-			char* _tmp39;
-			_tmp39 = NULL;
-			vala_report_error (NULL, _tmp39 = g_strdup_printf ("cc exited with status %d", exit_status));
-			_tmp39 = (g_free (_tmp39), NULL);
+			char* _tmp34_;
+			_tmp34_ = NULL;
+			vala_report_error (NULL, _tmp34_ = g_strdup_printf ("cc exited with status %d", exit_status));
+			_tmp34_ = (g_free (_tmp34_), NULL);
 		}
 	}
 	goto __finally2;
 	__catch2_g_spawn_error:
 	{
 		GError * e;
-		e = inner_error;
-		inner_error = NULL;
+		e = _inner_error_;
+		_inner_error_ = NULL;
 		{
 			vala_report_error (NULL, e->message);
 			(e == NULL) ? NULL : (e = (g_error_free (e), NULL));
 		}
 	}
 	__finally2:
-	if (inner_error != NULL) {
+	if (_inner_error_ != NULL) {
 		pc = (g_free (pc), NULL);
 		pkgflags = (g_free (pkgflags), NULL);
 		cmdline = (g_free (cmdline), NULL);
 		(source_files == NULL) ? NULL : (source_files = (gee_collection_object_unref (source_files), NULL));
 		(c_source_files == NULL) ? NULL : (c_source_files = (gee_collection_object_unref (c_source_files), NULL));
-		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, inner_error->message);
-		g_clear_error (&inner_error);
+		g_critical ("file %s: line %d: uncaught error: %s", __FILE__, __LINE__, _inner_error_->message);
+		g_clear_error (&_inner_error_);
 		return;
 	}
 	/* remove generated C source and header files */
@@ -405,24 +422,11 @@ void vala_ccode_compiler_compile (ValaCCodeCompiler* self, ValaCodeContext* cont
 			/* remove generated C source and header files */
 			file = (ValaSourceFile*) gee_iterator_get (_file_it);
 			if (!vala_source_file_get_external_package (file)) {
-				gboolean _tmp41;
 				if (!vala_code_context_get_save_csources (context)) {
-					char* _tmp40;
-					_tmp40 = NULL;
-					g_unlink (_tmp40 = vala_source_file_get_csource_filename (file));
-					_tmp40 = (g_free (_tmp40), NULL);
-				}
-				_tmp41 = FALSE;
-				if (vala_code_context_get_legacy_headers (context)) {
-					_tmp41 = !vala_code_context_get_save_cheaders (context);
-				} else {
-					_tmp41 = FALSE;
-				}
-				if (_tmp41) {
-					char* _tmp42;
-					_tmp42 = NULL;
-					g_unlink (_tmp42 = vala_source_file_get_cheader_filename (file));
-					_tmp42 = (g_free (_tmp42), NULL);
+					char* _tmp35_;
+					_tmp35_ = NULL;
+					g_unlink (_tmp35_ = vala_source_file_get_csource_filename (file));
+					_tmp35_ = (g_free (_tmp35_), NULL);
 				}
 			}
 			(file == NULL) ? NULL : (file = (vala_source_file_unref (file), NULL));
