@@ -408,7 +408,7 @@ static void vala_ccode_generator_finalize (ValaCodeVisitor* obj);
 
 ValaCCodeGenerator* vala_ccode_generator_construct (GType object_type) {
 	ValaCCodeGenerator* self;
-	ValaCCodeModule* _tmp0;
+	ValaCCodeModule* _tmp0_;
 	self = (ValaCCodeGenerator*) g_type_create_instance (object_type);
 	/* included by inheritance
 	head = new CCodeBaseModule (this, head);
@@ -427,8 +427,8 @@ ValaCCodeGenerator* vala_ccode_generator_construct (GType object_type) {
 	head = new GAsyncModule (this, head);
 	head = new DBusClientModule (this, head);
 	*/
-	_tmp0 = NULL;
-	self->head = (_tmp0 = (ValaCCodeModule*) vala_dbus_server_module_new (self, self->head), (self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)), _tmp0);
+	_tmp0_ = NULL;
+	self->head = (_tmp0_ = (ValaCCodeModule*) vala_dbus_server_module_new (self, self->head), (self->head == NULL) ? NULL : (self->head = (vala_ccode_module_unref (self->head), NULL)), _tmp0_);
 	return self;
 }
 
