@@ -20,33 +20,105 @@
  * 	Jürg Billeter <j@bitron.ch>
  */
 
-#include <gobject/valaclassregisterfunction.h>
-#include <gee/iterable.h>
-#include <gee/iterator.h>
-#include <vala/valadatatype.h>
-#include <vala/valainterface.h>
-#include <ccode/valaccodedeclaration.h>
-#include <ccode/valaccodemodifiers.h>
-#include <ccode/valaccodevariabledeclarator.h>
-#include <ccode/valaccodeconstant.h>
-#include <ccode/valaccodeexpression.h>
-#include <ccode/valaccodedeclarator.h>
-#include <ccode/valaccodenode.h>
-#include <ccode/valaccodefunctioncall.h>
-#include <ccode/valaccodeidentifier.h>
-#include <ccode/valaccodeexpressionstatement.h>
+#include <glib.h>
+#include <glib-object.h>
+#include <vala.h>
+#include <stdlib.h>
+#include <string.h>
+#include <valaccode.h>
+#include <gee.h>
 
 
+#define VALA_TYPE_TYPEREGISTER_FUNCTION (vala_typeregister_function_get_type ())
+#define VALA_TYPEREGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunction))
+#define VALA_TYPEREGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionClass))
+#define VALA_IS_TYPEREGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION))
+#define VALA_IS_TYPEREGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_TYPEREGISTER_FUNCTION))
+#define VALA_TYPEREGISTER_FUNCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_TYPEREGISTER_FUNCTION, ValaTypeRegisterFunctionClass))
 
+typedef struct _ValaTypeRegisterFunction ValaTypeRegisterFunction;
+typedef struct _ValaTypeRegisterFunctionClass ValaTypeRegisterFunctionClass;
+typedef struct _ValaTypeRegisterFunctionPrivate ValaTypeRegisterFunctionPrivate;
+
+#define VALA_TYPE_CLASS_REGISTER_FUNCTION (vala_class_register_function_get_type ())
+#define VALA_CLASS_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_CLASS_REGISTER_FUNCTION, ValaClassRegisterFunction))
+#define VALA_CLASS_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_CLASS_REGISTER_FUNCTION, ValaClassRegisterFunctionClass))
+#define VALA_IS_CLASS_REGISTER_FUNCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_CLASS_REGISTER_FUNCTION))
+#define VALA_IS_CLASS_REGISTER_FUNCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_CLASS_REGISTER_FUNCTION))
+#define VALA_CLASS_REGISTER_FUNCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_CLASS_REGISTER_FUNCTION, ValaClassRegisterFunctionClass))
+
+typedef struct _ValaClassRegisterFunction ValaClassRegisterFunction;
+typedef struct _ValaClassRegisterFunctionClass ValaClassRegisterFunctionClass;
+typedef struct _ValaClassRegisterFunctionPrivate ValaClassRegisterFunctionPrivate;
+
+/**
+ * C function to register a type at runtime.
+ */
+struct _ValaTypeRegisterFunction {
+	GTypeInstance parent_instance;
+	volatile int ref_count;
+	ValaTypeRegisterFunctionPrivate * priv;
+};
+
+struct _ValaTypeRegisterFunctionClass {
+	GTypeClass parent_class;
+	void (*finalize) (ValaTypeRegisterFunction *self);
+	ValaTypeSymbol* (*get_type_declaration) (ValaTypeRegisterFunction* self);
+	char* (*get_type_struct_name) (ValaTypeRegisterFunction* self);
+	char* (*get_base_init_func_name) (ValaTypeRegisterFunction* self);
+	char* (*get_class_finalize_func_name) (ValaTypeRegisterFunction* self);
+	char* (*get_base_finalize_func_name) (ValaTypeRegisterFunction* self);
+	char* (*get_class_init_func_name) (ValaTypeRegisterFunction* self);
+	char* (*get_instance_struct_size) (ValaTypeRegisterFunction* self);
+	char* (*get_instance_init_func_name) (ValaTypeRegisterFunction* self);
+	char* (*get_parent_type_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_init_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_peek_pointer_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_free_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_copy_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_lcopy_value_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_gtype_value_table_collect_value_function_name) (ValaTypeRegisterFunction* self);
+	char* (*get_type_flags) (ValaTypeRegisterFunction* self);
+	ValaCCodeFragment* (*get_type_interface_init_declaration) (ValaTypeRegisterFunction* self);
+	ValaCCodeFragment* (*get_type_interface_init_statements) (ValaTypeRegisterFunction* self);
+	ValaSymbolAccessibility (*get_accessibility) (ValaTypeRegisterFunction* self);
+};
+
+/**
+ * C function to register a class at runtime.
+ */
+struct _ValaClassRegisterFunction {
+	ValaTypeRegisterFunction parent_instance;
+	ValaClassRegisterFunctionPrivate * priv;
+};
+
+struct _ValaClassRegisterFunctionClass {
+	ValaTypeRegisterFunctionClass parent_class;
+};
 
 struct _ValaClassRegisterFunctionPrivate {
 	ValaClass* _class_reference;
 };
 
+
+
+gpointer vala_typeregister_function_ref (gpointer instance);
+void vala_typeregister_function_unref (gpointer instance);
+GParamSpec* vala_param_spec_typeregister_function (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
+void vala_value_set_typeregister_function (GValue* value, gpointer v_object);
+gpointer vala_value_get_typeregister_function (const GValue* value);
+GType vala_typeregister_function_get_type (void);
+GType vala_class_register_function_get_type (void);
 #define VALA_CLASS_REGISTER_FUNCTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), VALA_TYPE_CLASS_REGISTER_FUNCTION, ValaClassRegisterFunctionPrivate))
 enum  {
 	VALA_CLASS_REGISTER_FUNCTION_DUMMY_PROPERTY
 };
+void vala_class_register_function_set_class_reference (ValaClassRegisterFunction* self, ValaClass* value);
+void vala_typeregister_function_set_context (ValaTypeRegisterFunction* self, ValaCodeContext* value);
+ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, ValaCodeContext* context);
+ValaClassRegisterFunction* vala_class_register_function_construct (GType object_type, ValaClass* cl, ValaCodeContext* context);
+ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, ValaCodeContext* context);
+ValaClass* vala_class_register_function_get_class_reference (ValaClassRegisterFunction* self);
 static ValaTypeSymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base);
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base);
@@ -95,40 +167,40 @@ ValaClassRegisterFunction* vala_class_register_function_new (ValaClass* cl, Vala
 
 static ValaTypeSymbol* vala_class_register_function_real_get_type_declaration (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	ValaTypeSymbol* _tmp0;
+	ValaTypeSymbol* _tmp0_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = NULL;
-	return (_tmp0 = (ValaTypeSymbol*) self->priv->_class_reference, (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
+	_tmp0_ = NULL;
+	return (_tmp0_ = (ValaTypeSymbol*) self->priv->_class_reference, (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
 }
 
 
 static char* vala_class_register_function_real_get_type_struct_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%sClass", _tmp0 = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strdup_printf ("%sClass", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
 static char* vala_class_register_function_real_get_base_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (vala_class_get_class_constructor (self->priv->_class_reference) != NULL) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp0 = vala_class_get_has_class_private_fields (self->priv->_class_reference);
+		_tmp0_ = vala_class_get_has_class_private_fields (self->priv->_class_reference);
 	}
-	if (_tmp0) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_base_init", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+	if (_tmp0_) {
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_base_init", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	} else {
 		return g_strdup ("NULL");
 	}
@@ -139,11 +211,11 @@ static char* vala_class_register_function_real_get_class_finalize_func_name (Val
 	ValaClassRegisterFunction * self;
 	self = (ValaClassRegisterFunction*) base;
 	if (vala_class_get_static_destructor (self->priv->_class_reference) != NULL) {
-		char* _tmp0;
-		char* _tmp1;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		return (_tmp1 = g_strdup_printf ("%s_class_finalize", _tmp0 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+		char* _tmp0_;
+		char* _tmp1_;
+		_tmp0_ = NULL;
+		_tmp1_ = NULL;
+		return (_tmp1_ = g_strdup_printf ("%s_class_finalize", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 	} else {
 		return g_strdup ("NULL");
 	}
@@ -152,20 +224,20 @@ static char* vala_class_register_function_real_get_class_finalize_func_name (Val
 
 static char* vala_class_register_function_real_get_base_finalize_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (vala_class_get_class_destructor (self->priv->_class_reference) != NULL) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		_tmp0 = vala_class_get_has_class_private_fields (self->priv->_class_reference);
+		_tmp0_ = vala_class_get_has_class_private_fields (self->priv->_class_reference);
 	}
-	if (_tmp0) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_base_finalize", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+	if (_tmp0_) {
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_base_finalize", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	} else {
 		return g_strdup ("NULL");
 	}
@@ -174,34 +246,34 @@ static char* vala_class_register_function_real_get_base_finalize_func_name (Vala
 
 static char* vala_class_register_function_real_get_class_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_class_init", _tmp0 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strdup_printf ("%s_class_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
 static char* vala_class_register_function_real_get_instance_struct_size (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("sizeof (%s)", _tmp0 = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strdup_printf ("sizeof (%s)", _tmp0_ = vala_typesymbol_get_cname ((ValaTypeSymbol*) self->priv->_class_reference, FALSE)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
 static char* vala_class_register_function_real_get_instance_init_func_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strdup_printf ("%s_instance_init", _tmp0 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strdup_printf ("%s_instance_init", _tmp0_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
@@ -232,22 +304,22 @@ static ValaSymbolAccessibility vala_class_register_function_real_get_accessibili
 
 static char* vala_class_register_function_real_get_gtype_value_table_init_function_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	gboolean is_fundamental;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!vala_class_get_is_compact (self->priv->_class_reference)) {
-		_tmp0 = vala_class_get_base_class (self->priv->_class_reference) == NULL;
+		_tmp0_ = vala_class_get_base_class (self->priv->_class_reference) == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	is_fundamental = _tmp0;
+	is_fundamental = _tmp0_;
 	if (is_fundamental) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_init", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_init", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	}
 	return NULL;
 }
@@ -255,22 +327,22 @@ static char* vala_class_register_function_real_get_gtype_value_table_init_functi
 
 static char* vala_class_register_function_real_get_gtype_value_table_free_function_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	gboolean is_fundamental;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!vala_class_get_is_compact (self->priv->_class_reference)) {
-		_tmp0 = vala_class_get_base_class (self->priv->_class_reference) == NULL;
+		_tmp0_ = vala_class_get_base_class (self->priv->_class_reference) == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	is_fundamental = _tmp0;
+	is_fundamental = _tmp0_;
 	if (is_fundamental) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_free_value", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_free_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	}
 	return NULL;
 }
@@ -278,22 +350,22 @@ static char* vala_class_register_function_real_get_gtype_value_table_free_functi
 
 static char* vala_class_register_function_real_get_gtype_value_table_copy_function_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	gboolean is_fundamental;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!vala_class_get_is_compact (self->priv->_class_reference)) {
-		_tmp0 = vala_class_get_base_class (self->priv->_class_reference) == NULL;
+		_tmp0_ = vala_class_get_base_class (self->priv->_class_reference) == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	is_fundamental = _tmp0;
+	is_fundamental = _tmp0_;
 	if (is_fundamental) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_copy_value", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_copy_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	}
 	return NULL;
 }
@@ -301,22 +373,22 @@ static char* vala_class_register_function_real_get_gtype_value_table_copy_functi
 
 static char* vala_class_register_function_real_get_gtype_value_table_peek_pointer_function_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	gboolean is_fundamental;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!vala_class_get_is_compact (self->priv->_class_reference)) {
-		_tmp0 = vala_class_get_base_class (self->priv->_class_reference) == NULL;
+		_tmp0_ = vala_class_get_base_class (self->priv->_class_reference) == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	is_fundamental = _tmp0;
+	is_fundamental = _tmp0_;
 	if (is_fundamental) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_peek_pointer", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_peek_pointer", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	}
 	return NULL;
 }
@@ -324,22 +396,22 @@ static char* vala_class_register_function_real_get_gtype_value_table_peek_pointe
 
 static char* vala_class_register_function_real_get_gtype_value_table_collect_value_function_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	gboolean is_fundamental;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!vala_class_get_is_compact (self->priv->_class_reference)) {
-		_tmp0 = vala_class_get_base_class (self->priv->_class_reference) == NULL;
+		_tmp0_ = vala_class_get_base_class (self->priv->_class_reference) == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	is_fundamental = _tmp0;
+	is_fundamental = _tmp0_;
 	if (is_fundamental) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_collect_value", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_collect_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	}
 	return NULL;
 }
@@ -347,22 +419,22 @@ static char* vala_class_register_function_real_get_gtype_value_table_collect_val
 
 static char* vala_class_register_function_real_get_gtype_value_table_lcopy_value_function_name (ValaTypeRegisterFunction* base) {
 	ValaClassRegisterFunction * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	gboolean is_fundamental;
 	self = (ValaClassRegisterFunction*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (!vala_class_get_is_compact (self->priv->_class_reference)) {
-		_tmp0 = vala_class_get_base_class (self->priv->_class_reference) == NULL;
+		_tmp0_ = vala_class_get_base_class (self->priv->_class_reference) == NULL;
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	is_fundamental = _tmp0;
+	is_fundamental = _tmp0_;
 	if (is_fundamental) {
-		char* _tmp1;
-		char* _tmp2;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		return (_tmp2 = g_strdup_printf ("%s_lcopy_value", _tmp1 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1 = (g_free (_tmp1), NULL), _tmp2);
+		char* _tmp1_;
+		char* _tmp2_;
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		return (_tmp2_ = g_strdup_printf ("%s_lcopy_value", _tmp1_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, "value_")), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_);
 	}
 	return NULL;
 }
@@ -374,48 +446,48 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 	self = (ValaClassRegisterFunction*) base;
 	frag = vala_ccode_fragment_new ();
 	{
-		GeeList* _tmp0;
-		GeeIterator* _tmp1;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _base_type_it;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		_base_type_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_class_get_base_types (self->priv->_class_reference))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_tmp0_ = NULL;
+		_tmp1_ = NULL;
+		_base_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (self->priv->_class_reference))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		while (gee_iterator_next (_base_type_it)) {
 			ValaDataType* base_type;
-			ValaInterface* _tmp2;
+			ValaInterface* _tmp2_;
 			ValaInterface* iface;
-			char* _tmp3;
-			char* _tmp4;
+			char* _tmp3_;
+			char* _tmp4_;
 			char* iface_info_name;
 			ValaCCodeDeclaration* ctypedecl;
-			ValaCCodeVariableDeclarator* _tmp9;
-			ValaCCodeConstant* _tmp8;
-			char* _tmp7;
-			char* _tmp6;
-			char* _tmp5;
+			ValaCCodeVariableDeclarator* _tmp9_;
+			ValaCCodeConstant* _tmp8_;
+			char* _tmp7_;
+			char* _tmp6_;
+			char* _tmp5_;
 			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
 			if (!VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type))) {
 				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 				continue;
 			}
-			_tmp2 = NULL;
-			iface = (_tmp2 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
-			_tmp3 = NULL;
-			_tmp4 = NULL;
-			iface_info_name = (_tmp4 = g_strdup_printf ("%s_info", _tmp3 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp3 = (g_free (_tmp3), NULL), _tmp4);
+			_tmp2_ = NULL;
+			iface = (_tmp2_ = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+			_tmp3_ = NULL;
+			_tmp4_ = NULL;
+			iface_info_name = (_tmp4_ = g_strdup_printf ("%s_info", _tmp3_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_);
 			ctypedecl = vala_ccode_declaration_new ("const GInterfaceInfo");
 			vala_ccode_declaration_set_modifiers (ctypedecl, VALA_CCODE_MODIFIERS_STATIC);
-			_tmp9 = NULL;
-			_tmp8 = NULL;
-			_tmp7 = NULL;
-			_tmp6 = NULL;
-			_tmp5 = NULL;
-			vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp9 = vala_ccode_variable_declarator_new (iface_info_name, (ValaCCodeExpression*) (_tmp8 = vala_ccode_constant_new (_tmp7 = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", _tmp5 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL), _tmp6 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)))))));
-			(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
-			(_tmp8 == NULL) ? NULL : (_tmp8 = (vala_ccode_node_unref (_tmp8), NULL));
-			_tmp7 = (g_free (_tmp7), NULL);
-			_tmp6 = (g_free (_tmp6), NULL);
-			_tmp5 = (g_free (_tmp5), NULL);
+			_tmp9_ = NULL;
+			_tmp8_ = NULL;
+			_tmp7_ = NULL;
+			_tmp6_ = NULL;
+			_tmp5_ = NULL;
+			vala_ccode_declaration_add_declarator (ctypedecl, (ValaCCodeDeclarator*) (_tmp9_ = vala_ccode_variable_declarator_new (iface_info_name, (ValaCCodeExpression*) (_tmp8_ = vala_ccode_constant_new (_tmp7_ = g_strdup_printf ("{ (GInterfaceInitFunc) %s_%s_interface_init, (GInterfaceFinalizeFunc) NULL, NULL}", _tmp5_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL), _tmp6_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)))), NULL)));
+			(_tmp9_ == NULL) ? NULL : (_tmp9_ = (vala_ccode_node_unref (_tmp9_), NULL));
+			(_tmp8_ == NULL) ? NULL : (_tmp8_ = (vala_ccode_node_unref (_tmp8_), NULL));
+			_tmp7_ = (g_free (_tmp7_), NULL);
+			_tmp6_ = (g_free (_tmp6_), NULL);
+			_tmp5_ = (g_free (_tmp5_), NULL);
 			vala_ccode_fragment_append (frag, (ValaCCodeNode*) ctypedecl);
 			(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 			(iface == NULL) ? NULL : (iface = (vala_code_node_unref (iface), NULL));
@@ -434,63 +506,63 @@ static ValaCCodeFragment* vala_class_register_function_real_get_type_interface_i
 	self = (ValaClassRegisterFunction*) base;
 	frag = vala_ccode_fragment_new ();
 	{
-		GeeList* _tmp0;
-		GeeIterator* _tmp1;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _base_type_it;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		_base_type_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_class_get_base_types (self->priv->_class_reference))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_tmp0_ = NULL;
+		_tmp1_ = NULL;
+		_base_type_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_class_get_base_types (self->priv->_class_reference))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		while (gee_iterator_next (_base_type_it)) {
 			ValaDataType* base_type;
-			ValaInterface* _tmp2;
+			ValaInterface* _tmp2_;
 			ValaInterface* iface;
-			char* _tmp3;
-			char* _tmp4;
+			char* _tmp3_;
+			char* _tmp4_;
 			char* iface_info_name;
-			ValaCCodeIdentifier* _tmp5;
-			ValaCCodeFunctionCall* _tmp6;
+			ValaCCodeIdentifier* _tmp5_;
+			ValaCCodeFunctionCall* _tmp6_;
 			ValaCCodeFunctionCall* reg_call;
-			ValaCCodeIdentifier* _tmp9;
-			char* _tmp8;
-			char* _tmp7;
-			ValaCCodeIdentifier* _tmp11;
-			char* _tmp10;
-			ValaCCodeIdentifier* _tmp13;
-			char* _tmp12;
-			ValaCCodeExpressionStatement* _tmp14;
+			ValaCCodeIdentifier* _tmp9_;
+			char* _tmp8_;
+			char* _tmp7_;
+			ValaCCodeIdentifier* _tmp11_;
+			char* _tmp10_;
+			ValaCCodeIdentifier* _tmp13_;
+			char* _tmp12_;
+			ValaCCodeExpressionStatement* _tmp14_;
 			base_type = (ValaDataType*) gee_iterator_get (_base_type_it);
 			if (!VALA_IS_INTERFACE (vala_data_type_get_data_type (base_type))) {
 				(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 				continue;
 			}
-			_tmp2 = NULL;
-			iface = (_tmp2 = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
-			_tmp3 = NULL;
-			_tmp4 = NULL;
-			iface_info_name = (_tmp4 = g_strdup_printf ("%s_info", _tmp3 = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp3 = (g_free (_tmp3), NULL), _tmp4);
-			_tmp5 = NULL;
-			_tmp6 = NULL;
-			reg_call = (_tmp6 = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp5 = vala_ccode_identifier_new ("g_type_add_interface_static"))), (_tmp5 == NULL) ? NULL : (_tmp5 = (vala_ccode_node_unref (_tmp5), NULL)), _tmp6);
-			_tmp9 = NULL;
-			_tmp8 = NULL;
-			_tmp7 = NULL;
-			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp9 = vala_ccode_identifier_new (_tmp8 = g_strdup_printf ("%s_type_id", _tmp7 = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)))));
-			(_tmp9 == NULL) ? NULL : (_tmp9 = (vala_ccode_node_unref (_tmp9), NULL));
-			_tmp8 = (g_free (_tmp8), NULL);
-			_tmp7 = (g_free (_tmp7), NULL);
-			_tmp11 = NULL;
-			_tmp10 = NULL;
-			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp11 = vala_ccode_identifier_new (_tmp10 = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface))));
-			(_tmp11 == NULL) ? NULL : (_tmp11 = (vala_ccode_node_unref (_tmp11), NULL));
-			_tmp10 = (g_free (_tmp10), NULL);
-			_tmp13 = NULL;
-			_tmp12 = NULL;
-			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp13 = vala_ccode_identifier_new (_tmp12 = g_strdup_printf ("&%s", iface_info_name))));
-			(_tmp13 == NULL) ? NULL : (_tmp13 = (vala_ccode_node_unref (_tmp13), NULL));
-			_tmp12 = (g_free (_tmp12), NULL);
-			_tmp14 = NULL;
-			vala_ccode_fragment_append (frag, (ValaCCodeNode*) (_tmp14 = vala_ccode_expression_statement_new ((ValaCCodeExpression*) reg_call)));
-			(_tmp14 == NULL) ? NULL : (_tmp14 = (vala_ccode_node_unref (_tmp14), NULL));
+			_tmp2_ = NULL;
+			iface = (_tmp2_ = VALA_INTERFACE (vala_data_type_get_data_type (base_type)), (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
+			_tmp3_ = NULL;
+			_tmp4_ = NULL;
+			iface_info_name = (_tmp4_ = g_strdup_printf ("%s_info", _tmp3_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) iface, NULL)), _tmp3_ = (g_free (_tmp3_), NULL), _tmp4_);
+			_tmp5_ = NULL;
+			_tmp6_ = NULL;
+			reg_call = (_tmp6_ = vala_ccode_function_call_new ((ValaCCodeExpression*) (_tmp5_ = vala_ccode_identifier_new ("g_type_add_interface_static"))), (_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_ccode_node_unref (_tmp5_), NULL)), _tmp6_);
+			_tmp9_ = NULL;
+			_tmp8_ = NULL;
+			_tmp7_ = NULL;
+			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp9_ = vala_ccode_identifier_new (_tmp8_ = g_strdup_printf ("%s_type_id", _tmp7_ = vala_symbol_get_lower_case_cname ((ValaSymbol*) self->priv->_class_reference, NULL)))));
+			(_tmp9_ == NULL) ? NULL : (_tmp9_ = (vala_ccode_node_unref (_tmp9_), NULL));
+			_tmp8_ = (g_free (_tmp8_), NULL);
+			_tmp7_ = (g_free (_tmp7_), NULL);
+			_tmp11_ = NULL;
+			_tmp10_ = NULL;
+			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp11_ = vala_ccode_identifier_new (_tmp10_ = vala_typesymbol_get_type_id ((ValaTypeSymbol*) iface))));
+			(_tmp11_ == NULL) ? NULL : (_tmp11_ = (vala_ccode_node_unref (_tmp11_), NULL));
+			_tmp10_ = (g_free (_tmp10_), NULL);
+			_tmp13_ = NULL;
+			_tmp12_ = NULL;
+			vala_ccode_function_call_add_argument (reg_call, (ValaCCodeExpression*) (_tmp13_ = vala_ccode_identifier_new (_tmp12_ = g_strdup_printf ("&%s", iface_info_name))));
+			(_tmp13_ == NULL) ? NULL : (_tmp13_ = (vala_ccode_node_unref (_tmp13_), NULL));
+			_tmp12_ = (g_free (_tmp12_), NULL);
+			_tmp14_ = NULL;
+			vala_ccode_fragment_append (frag, (ValaCCodeNode*) (_tmp14_ = vala_ccode_expression_statement_new ((ValaCCodeExpression*) reg_call)));
+			(_tmp14_ == NULL) ? NULL : (_tmp14_ = (vala_ccode_node_unref (_tmp14_), NULL));
 			(base_type == NULL) ? NULL : (base_type = (vala_code_node_unref (base_type), NULL));
 			(iface == NULL) ? NULL : (iface = (vala_code_node_unref (iface), NULL));
 			iface_info_name = (g_free (iface_info_name), NULL);
