@@ -1036,7 +1036,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1266,10 +1265,10 @@ static gboolean vala_base_access_real_check (ValaCodeNode* base, ValaSemanticAna
 			vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) self), "Base access invalid without base class");
 			return FALSE;
 		} else {
-			ValaObjectType* _tmp5;
-			_tmp5 = NULL;
-			vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp5 = vala_object_type_new ((ValaObjectTypeSymbol*) vala_class_get_base_class (analyzer->current_class))));
-			(_tmp5 == NULL) ? NULL : (_tmp5 = (vala_code_node_unref (_tmp5), NULL));
+			ValaObjectType* _tmp5_;
+			_tmp5_ = NULL;
+			vala_expression_set_value_type ((ValaExpression*) self, (ValaDataType*) (_tmp5_ = vala_object_type_new ((ValaObjectTypeSymbol*) vala_class_get_base_class (analyzer->current_class))));
+			(_tmp5_ == NULL) ? NULL : (_tmp5_ = (vala_code_node_unref (_tmp5_), NULL));
 		}
 	}
 	vala_expression_set_symbol_reference ((ValaExpression*) self, (ValaSymbol*) vala_data_type_get_data_type (vala_expression_get_value_type ((ValaExpression*) self)));
