@@ -328,30 +328,30 @@ ValaEnumValue* vala_enum_value_new_with_value (const char* name, ValaExpression*
  */
 ValaCCodeConstant* vala_enum_value_get_canonical_cconstant (ValaEnumValue* self) {
 	GString* str;
-	const char* _tmp0;
+	const char* _tmp0_;
 	char* i;
-	ValaCCodeConstant* _tmp3;
+	ValaCCodeConstant* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
 	str = g_string_new ("\"");
-	_tmp0 = NULL;
-	i = (_tmp0 = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0 == NULL) ? NULL : g_strdup (_tmp0));
+	_tmp0_ = NULL;
+	i = (_tmp0_ = vala_symbol_get_name ((ValaSymbol*) self), (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_));
 	while (g_utf8_strlen (i, -1) > 0) {
 		gunichar c;
-		char* _tmp2;
-		const char* _tmp1;
+		char* _tmp2_;
+		const char* _tmp1_;
 		c = g_utf8_get_char (i);
 		if (c == '_') {
 			g_string_append_c (str, '-');
 		} else {
 			g_string_append_unichar (str, g_unichar_tolower (c));
 		}
-		_tmp2 = NULL;
-		_tmp1 = NULL;
-		i = (_tmp2 = (_tmp1 = g_utf8_next_char (i), (_tmp1 == NULL) ? NULL : g_strdup (_tmp1)), i = (g_free (i), NULL), _tmp2);
+		_tmp2_ = NULL;
+		_tmp1_ = NULL;
+		i = (_tmp2_ = (_tmp1_ = g_utf8_next_char (i), (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_)), i = (g_free (i), NULL), _tmp2_);
 	}
 	g_string_append_c (str, '"');
-	_tmp3 = NULL;
-	return (_tmp3 = vala_ccode_constant_new (str->str), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp3);
+	_tmp3_ = NULL;
+	return (_tmp3_ = vala_ccode_constant_new (str->str), (str == NULL) ? NULL : (str = (g_string_free (str, TRUE), NULL)), i = (g_free (i), NULL), _tmp3_);
 }
 
 
@@ -383,22 +383,22 @@ void vala_enum_value_process_attributes (ValaEnumValue* self) {
 		GList* a_it;
 		a_collection = ((ValaCodeNode*) self)->attributes;
 		for (a_it = a_collection; a_it != NULL; a_it = a_it->next) {
-			ValaAttribute* _tmp2;
+			ValaAttribute* _tmp2_;
 			ValaAttribute* a;
-			_tmp2 = NULL;
-			a = (_tmp2 = (ValaAttribute*) a_it->data, (_tmp2 == NULL) ? NULL : vala_code_node_ref (_tmp2));
+			_tmp2_ = NULL;
+			a = (_tmp2_ = (ValaAttribute*) a_it->data, (_tmp2_ == NULL) ? NULL : vala_code_node_ref (_tmp2_));
 			{
-				gboolean _tmp0;
-				_tmp0 = FALSE;
+				gboolean _tmp0_;
+				_tmp0_ = FALSE;
 				if (_vala_strcmp0 (vala_attribute_get_name (a), "CCode") == 0) {
-					_tmp0 = vala_attribute_has_argument (a, "cname");
+					_tmp0_ = vala_attribute_has_argument (a, "cname");
 				} else {
-					_tmp0 = FALSE;
+					_tmp0_ = FALSE;
 				}
-				if (_tmp0) {
-					char* _tmp1;
-					_tmp1 = NULL;
-					self->priv->cname = (_tmp1 = vala_attribute_get_string (a, "cname"), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1);
+				if (_tmp0_) {
+					char* _tmp1_;
+					_tmp1_ = NULL;
+					self->priv->cname = (_tmp1_ = vala_attribute_get_string (a, "cname"), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
 				}
 				(a == NULL) ? NULL : (a = (vala_code_node_unref (a), NULL));
 			}
@@ -413,31 +413,31 @@ void vala_enum_value_process_attributes (ValaEnumValue* self) {
  * @return the name to be used in C code
  */
 char* vala_enum_value_get_cname (ValaEnumValue* self) {
-	const char* _tmp1;
+	const char* _tmp1_;
 	g_return_val_if_fail (self != NULL, NULL);
 	if (self->priv->cname == NULL) {
-		char* _tmp0;
-		_tmp0 = NULL;
-		self->priv->cname = (_tmp0 = vala_enum_value_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0);
+		char* _tmp0_;
+		_tmp0_ = NULL;
+		self->priv->cname = (_tmp0_ = vala_enum_value_get_default_cname (self), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp0_);
 	}
-	_tmp1 = NULL;
-	return (_tmp1 = self->priv->cname, (_tmp1 == NULL) ? NULL : g_strdup (_tmp1));
+	_tmp1_ = NULL;
+	return (_tmp1_ = self->priv->cname, (_tmp1_ == NULL) ? NULL : g_strdup (_tmp1_));
 }
 
 
 char* vala_enum_value_get_default_cname (ValaEnumValue* self) {
-	ValaEnum* _tmp0;
+	ValaEnum* _tmp0_;
 	ValaEnum* en;
-	char* _tmp1;
-	char* _tmp2;
-	char* _tmp3;
+	char* _tmp1_;
+	char* _tmp2_;
+	char* _tmp3_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0 = NULL;
-	en = (_tmp0 = VALA_ENUM (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
-	_tmp1 = NULL;
-	_tmp2 = NULL;
-	_tmp3 = NULL;
-	return (_tmp3 = (_tmp2 = g_strdup_printf ("%s%s", _tmp1 = vala_symbol_get_cprefix ((ValaSymbol*) en), vala_symbol_get_name ((ValaSymbol*) self)), _tmp1 = (g_free (_tmp1), NULL), _tmp2), (en == NULL) ? NULL : (en = (vala_code_node_unref (en), NULL)), _tmp3);
+	_tmp0_ = NULL;
+	en = (_tmp0_ = VALA_ENUM (vala_symbol_get_parent_symbol ((ValaSymbol*) self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
+	_tmp1_ = NULL;
+	_tmp2_ = NULL;
+	_tmp3_ = NULL;
+	return (_tmp3_ = (_tmp2_ = g_strdup_printf ("%s%s", _tmp1_ = vala_symbol_get_cprefix ((ValaSymbol*) en), vala_symbol_get_name ((ValaSymbol*) self)), _tmp1_ = (g_free (_tmp1_), NULL), _tmp2_), (en == NULL) ? NULL : (en = (vala_code_node_unref (en), NULL)), _tmp3_);
 }
 
 
@@ -447,13 +447,13 @@ char* vala_enum_value_get_default_cname (ValaEnumValue* self) {
  * @param cname the name to be used in C code
  */
 void vala_enum_value_set_cname (ValaEnumValue* self, const char* cname) {
-	char* _tmp1;
-	const char* _tmp0;
+	char* _tmp1_;
+	const char* _tmp0_;
 	g_return_if_fail (self != NULL);
 	g_return_if_fail (cname != NULL);
-	_tmp1 = NULL;
-	_tmp0 = NULL;
-	self->priv->cname = (_tmp1 = (_tmp0 = cname, (_tmp0 == NULL) ? NULL : g_strdup (_tmp0)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1);
+	_tmp1_ = NULL;
+	_tmp0_ = NULL;
+	self->priv->cname = (_tmp1_ = (_tmp0_ = cname, (_tmp0_ == NULL) ? NULL : g_strdup (_tmp0_)), self->priv->cname = (g_free (self->priv->cname), NULL), _tmp1_);
 }
 
 
@@ -480,12 +480,12 @@ ValaExpression* vala_enum_value_get_value (ValaEnumValue* self) {
 
 
 void vala_enum_value_set_value (ValaEnumValue* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_value = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_value == NULL) ? NULL : (self->priv->_value = (vala_code_node_unref (self->priv->_value), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_value = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_value == NULL) ? NULL : (self->priv->_value = (vala_code_node_unref (self->priv->_value), NULL)), _tmp2_);
 }
 
 
