@@ -1020,7 +1020,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1242,8 +1241,8 @@ static void vala_if_statement_real_replace_expression (ValaCodeNode* base, ValaE
 
 static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaIfStatement * self;
-	GeeList* _tmp3;
-	GeeList* _tmp4;
+	GeeList* _tmp3_;
+	GeeList* _tmp4_;
 	self = (ValaIfStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1265,17 +1264,17 @@ static gboolean vala_if_statement_real_check (ValaCodeNode* base, ValaSemanticAn
 		vala_report_error (vala_code_node_get_source_reference ((ValaCodeNode*) vala_if_statement_get_condition (self)), "Condition must be boolean");
 		return FALSE;
 	}
-	_tmp3 = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp3 = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_condition (self)));
-	(_tmp3 == NULL) ? NULL : (_tmp3 = (gee_collection_object_unref (_tmp3), NULL));
-	_tmp4 = NULL;
-	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp4 = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_true_statement));
-	(_tmp4 == NULL) ? NULL : (_tmp4 = (gee_collection_object_unref (_tmp4), NULL));
+	_tmp3_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp3_ = vala_code_node_get_error_types ((ValaCodeNode*) vala_if_statement_get_condition (self)));
+	(_tmp3_ == NULL) ? NULL : (_tmp3_ = (gee_collection_object_unref (_tmp3_), NULL));
+	_tmp4_ = NULL;
+	vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp4_ = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_true_statement));
+	(_tmp4_ == NULL) ? NULL : (_tmp4_ = (gee_collection_object_unref (_tmp4_), NULL));
 	if (self->priv->_false_statement != NULL) {
-		GeeList* _tmp5;
-		_tmp5 = NULL;
-		vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp5 = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_false_statement));
-		(_tmp5 == NULL) ? NULL : (_tmp5 = (gee_collection_object_unref (_tmp5), NULL));
+		GeeList* _tmp5_;
+		_tmp5_ = NULL;
+		vala_code_node_add_error_types ((ValaCodeNode*) self, _tmp5_ = vala_code_node_get_error_types ((ValaCodeNode*) self->priv->_false_statement));
+		(_tmp5_ == NULL) ? NULL : (_tmp5_ = (gee_collection_object_unref (_tmp5_), NULL));
 	}
 	return !vala_code_node_get_error ((ValaCodeNode*) self);
 }
@@ -1288,12 +1287,12 @@ ValaExpression* vala_if_statement_get_condition (ValaIfStatement* self) {
 
 
 void vala_if_statement_set_condition (ValaIfStatement* self, ValaExpression* value) {
-	ValaExpression* _tmp2;
-	ValaExpression* _tmp1;
+	ValaExpression* _tmp2_;
+	ValaExpression* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_condition = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_condition = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_condition == NULL) ? NULL : (self->priv->_condition = (vala_code_node_unref (self->priv->_condition), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_condition, (ValaCodeNode*) self);
 }
 
@@ -1305,12 +1304,12 @@ ValaBlock* vala_if_statement_get_true_statement (ValaIfStatement* self) {
 
 
 void vala_if_statement_set_true_statement (ValaIfStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp2;
-	ValaBlock* _tmp1;
+	ValaBlock* _tmp2_;
+	ValaBlock* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_true_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_true_statement = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_true_statement == NULL) ? NULL : (self->priv->_true_statement = (vala_code_node_unref (self->priv->_true_statement), NULL)), _tmp2_);
 }
 
 
@@ -1321,12 +1320,12 @@ ValaBlock* vala_if_statement_get_false_statement (ValaIfStatement* self) {
 
 
 void vala_if_statement_set_false_statement (ValaIfStatement* self, ValaBlock* value) {
-	ValaBlock* _tmp2;
-	ValaBlock* _tmp1;
+	ValaBlock* _tmp2_;
+	ValaBlock* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_false_statement = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_false_statement = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_false_statement == NULL) ? NULL : (self->priv->_false_statement = (vala_code_node_unref (self->priv->_false_statement), NULL)), _tmp2_);
 }
 
 
