@@ -208,6 +208,7 @@ struct _ValaDataType {
 struct _ValaDataTypeClass {
 	ValaCodeNodeClass parent_class;
 	char* (*get_cname) (ValaDataType* self);
+	char* (*get_cdeclarator_suffix) (ValaDataType* self);
 	char* (*get_lower_case_cname) (ValaDataType* self, const char* infix);
 	char* (*to_qualified_string) (ValaDataType* self, ValaScope* scope);
 	ValaDataType* (*copy) (ValaDataType* self);
@@ -341,70 +342,70 @@ ValaPointerType* vala_pointer_type_new (ValaDataType* base_type, ValaSourceRefer
 
 static char* vala_pointer_type_real_to_qualified_string (ValaDataType* base, ValaScope* scope) {
 	ValaPointerType * self;
-	char* _tmp0;
-	char* _tmp1;
+	char* _tmp0_;
+	char* _tmp1_;
 	self = (ValaPointerType*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = g_strconcat (_tmp0 = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _tmp0 = (g_free (_tmp0), NULL), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = g_strconcat (_tmp0_ = vala_data_type_to_qualified_string (vala_pointer_type_get_base_type (self), scope), "*", NULL), _tmp0_ = (g_free (_tmp0_), NULL), _tmp1_);
 }
 
 
 static char* vala_pointer_type_real_get_cname (ValaDataType* base) {
 	ValaPointerType * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaPointerType*) base;
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)) != NULL) {
-		_tmp0 = vala_typesymbol_is_reference_type (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)));
+		_tmp0_ = vala_typesymbol_is_reference_type (vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)));
 	} else {
-		_tmp0 = FALSE;
+		_tmp0_ = FALSE;
 	}
-	if (_tmp0) {
+	if (_tmp0_) {
 		return vala_data_type_get_cname (vala_pointer_type_get_base_type (self));
 	} else {
-		char* _tmp2;
-		char* _tmp3;
-		_tmp2 = NULL;
-		_tmp3 = NULL;
-		return (_tmp3 = g_strconcat (_tmp2 = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _tmp2 = (g_free (_tmp2), NULL), _tmp3);
+		char* _tmp2_;
+		char* _tmp3_;
+		_tmp2_ = NULL;
+		_tmp3_ = NULL;
+		return (_tmp3_ = g_strconcat (_tmp2_ = vala_data_type_get_cname (vala_pointer_type_get_base_type (self)), "*", NULL), _tmp2_ = (g_free (_tmp2_), NULL), _tmp3_);
 	}
 }
 
 
 static ValaDataType* vala_pointer_type_real_copy (ValaDataType* base) {
 	ValaPointerType * self;
-	ValaDataType* _tmp0;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp0_;
+	ValaDataType* _tmp1_;
 	self = (ValaPointerType*) base;
-	_tmp0 = NULL;
-	_tmp1 = NULL;
-	return (_tmp1 = (ValaDataType*) vala_pointer_type_new (_tmp0 = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), (_tmp0 == NULL) ? NULL : (_tmp0 = (vala_code_node_unref (_tmp0), NULL)), _tmp1);
+	_tmp0_ = NULL;
+	_tmp1_ = NULL;
+	return (_tmp1_ = (ValaDataType*) vala_pointer_type_new (_tmp0_ = vala_data_type_copy (vala_pointer_type_get_base_type (self)), NULL), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (vala_code_node_unref (_tmp0_), NULL)), _tmp1_);
 }
 
 
 static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataType* target_type) {
 	ValaPointerType * self;
-	gboolean _tmp0;
+	gboolean _tmp0_;
 	self = (ValaPointerType*) base;
 	g_return_val_if_fail (target_type != NULL, FALSE);
-	_tmp0 = FALSE;
+	_tmp0_ = FALSE;
 	if (VALA_IS_POINTER_TYPE (target_type)) {
-		_tmp0 = TRUE;
+		_tmp0_ = TRUE;
 	} else {
-		gboolean _tmp1;
-		_tmp1 = FALSE;
+		gboolean _tmp1_;
+		_tmp1_ = FALSE;
 		if (vala_data_type_get_data_type (target_type) != NULL) {
-			ValaAttribute* _tmp2;
-			_tmp2 = NULL;
-			_tmp1 = (_tmp2 = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
-			(_tmp2 == NULL) ? NULL : (_tmp2 = (vala_code_node_unref (_tmp2), NULL));
+			ValaAttribute* _tmp2_;
+			_tmp2_ = NULL;
+			_tmp1_ = (_tmp2_ = vala_code_node_get_attribute ((ValaCodeNode*) vala_data_type_get_data_type (target_type), "PointerType")) != NULL;
+			(_tmp2_ == NULL) ? NULL : (_tmp2_ = (vala_code_node_unref (_tmp2_), NULL));
 		} else {
-			_tmp1 = FALSE;
+			_tmp1_ = FALSE;
 		}
-		_tmp0 = _tmp1;
+		_tmp0_ = _tmp1_;
 	}
-	if (_tmp0) {
+	if (_tmp0_) {
 		return TRUE;
 	}
 	/* temporarily ignore type parameters */
@@ -421,20 +422,20 @@ static gboolean vala_pointer_type_real_compatible (ValaDataType* base, ValaDataT
 
 static ValaSymbol* vala_pointer_type_real_get_pointer_member (ValaDataType* base, const char* member_name) {
 	ValaPointerType * self;
-	ValaSymbol* _tmp0;
+	ValaSymbol* _tmp0_;
 	ValaSymbol* base_symbol;
-	ValaSymbol* _tmp2;
+	ValaSymbol* _tmp2_;
 	self = (ValaPointerType*) base;
 	g_return_val_if_fail (member_name != NULL, NULL);
-	_tmp0 = NULL;
-	base_symbol = (_tmp0 = (ValaSymbol*) vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)), (_tmp0 == NULL) ? NULL : vala_code_node_ref (_tmp0));
+	_tmp0_ = NULL;
+	base_symbol = (_tmp0_ = (ValaSymbol*) vala_data_type_get_data_type (vala_pointer_type_get_base_type (self)), (_tmp0_ == NULL) ? NULL : vala_code_node_ref (_tmp0_));
 	if (base_symbol == NULL) {
-		ValaSymbol* _tmp1;
-		_tmp1 = NULL;
-		return (_tmp1 = NULL, (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp1);
+		ValaSymbol* _tmp1_;
+		_tmp1_ = NULL;
+		return (_tmp1_ = NULL, (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp1_);
 	}
-	_tmp2 = NULL;
-	return (_tmp2 = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	return (_tmp2_ = vala_semantic_analyzer_symbol_lookup_inherited (base_symbol, member_name), (base_symbol == NULL) ? NULL : (base_symbol = (vala_code_node_unref (base_symbol), NULL)), _tmp2_);
 }
 
 
@@ -494,12 +495,12 @@ ValaDataType* vala_pointer_type_get_base_type (ValaPointerType* self) {
 
 
 void vala_pointer_type_set_base_type (ValaPointerType* self, ValaDataType* value) {
-	ValaDataType* _tmp2;
-	ValaDataType* _tmp1;
+	ValaDataType* _tmp2_;
+	ValaDataType* _tmp1_;
 	g_return_if_fail (self != NULL);
-	_tmp2 = NULL;
-	_tmp1 = NULL;
-	self->priv->_base_type = (_tmp2 = (_tmp1 = value, (_tmp1 == NULL) ? NULL : vala_code_node_ref (_tmp1)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp2);
+	_tmp2_ = NULL;
+	_tmp1_ = NULL;
+	self->priv->_base_type = (_tmp2_ = (_tmp1_ = value, (_tmp1_ == NULL) ? NULL : vala_code_node_ref (_tmp1_)), (self->priv->_base_type == NULL) ? NULL : (self->priv->_base_type = (vala_code_node_unref (self->priv->_base_type), NULL)), _tmp2_);
 	vala_code_node_set_parent_node ((ValaCodeNode*) self->priv->_base_type, (ValaCodeNode*) self);
 }
 
