@@ -1058,7 +1058,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1272,8 +1271,8 @@ gboolean vala_switch_section_has_default_label (ValaSwitchSection* self) {
 			ValaSwitchLabel* label;
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
 			if (vala_switch_label_get_expression (label) == NULL) {
-				gboolean _tmp0;
-				return (_tmp0 = TRUE, (label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL)), (_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL)), _tmp0);
+				gboolean _tmp0_;
+				return (_tmp0_ = TRUE, (label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL)), (_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL)), _tmp0_);
 			}
 			(label == NULL) ? NULL : (label = (vala_code_node_unref (label), NULL));
 		}
@@ -1307,12 +1306,12 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
 	}
 	{
-		GeeList* _tmp0;
-		GeeIterator* _tmp1;
+		GeeList* _tmp0_;
+		GeeIterator* _tmp1_;
 		GeeIterator* _st_it;
-		_tmp0 = NULL;
-		_tmp1 = NULL;
-		_st_it = (_tmp1 = gee_iterable_iterator ((GeeIterable*) (_tmp0 = vala_block_get_statements ((ValaBlock*) self))), (_tmp0 == NULL) ? NULL : (_tmp0 = (gee_collection_object_unref (_tmp0), NULL)), _tmp1);
+		_tmp0_ = NULL;
+		_tmp1_ = NULL;
+		_st_it = (_tmp1_ = gee_iterable_iterator ((GeeIterable*) (_tmp0_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp0_ == NULL) ? NULL : (_tmp0_ = (gee_collection_object_unref (_tmp0_), NULL)), _tmp1_);
 		while (gee_iterator_next (_st_it)) {
 			ValaStatement* st;
 			st = (ValaStatement*) gee_iterator_get (_st_it);
@@ -1326,15 +1325,15 @@ static void vala_switch_section_real_accept_children (ValaCodeNode* base, ValaCo
 
 static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSwitchSection * self;
-	ValaSymbol* _tmp3;
+	ValaSymbol* _tmp3_;
 	ValaSymbol* old_symbol;
-	ValaBlock* _tmp4;
+	ValaBlock* _tmp4_;
 	ValaBlock* old_insert_block;
-	ValaBlock* _tmp6;
-	ValaBlock* _tmp5;
-	ValaBlock* _tmp12;
-	ValaBlock* _tmp11;
-	gboolean _tmp13;
+	ValaBlock* _tmp6_;
+	ValaBlock* _tmp5_;
+	ValaBlock* _tmp12_;
+	ValaBlock* _tmp11_;
+	gboolean _tmp13_;
 	self = (ValaSwitchSection*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1342,12 +1341,12 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 	}
 	vala_code_node_set_checked ((ValaCodeNode*) self, TRUE);
 	{
-		GeeList* _tmp1;
-		GeeIterator* _tmp2;
+		GeeList* _tmp1_;
+		GeeIterator* _tmp2_;
 		GeeIterator* _label_it;
-		_tmp1 = NULL;
-		_tmp2 = NULL;
-		_label_it = (_tmp2 = gee_iterable_iterator ((GeeIterable*) (_tmp1 = vala_switch_section_get_labels (self))), (_tmp1 == NULL) ? NULL : (_tmp1 = (gee_collection_object_unref (_tmp1), NULL)), _tmp2);
+		_tmp1_ = NULL;
+		_tmp2_ = NULL;
+		_label_it = (_tmp2_ = gee_iterable_iterator ((GeeIterable*) (_tmp1_ = vala_switch_section_get_labels (self))), (_tmp1_ == NULL) ? NULL : (_tmp1_ = (gee_collection_object_unref (_tmp1_), NULL)), _tmp2_);
 		while (gee_iterator_next (_label_it)) {
 			ValaSwitchLabel* label;
 			label = (ValaSwitchLabel*) gee_iterator_get (_label_it);
@@ -1357,21 +1356,21 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		(_label_it == NULL) ? NULL : (_label_it = (gee_collection_object_unref (_label_it), NULL));
 	}
 	vala_symbol_set_owner ((ValaSymbol*) self, vala_symbol_get_scope (vala_semantic_analyzer_get_current_symbol (analyzer)));
-	_tmp3 = NULL;
-	old_symbol = (_tmp3 = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp3 == NULL) ? NULL : vala_code_node_ref (_tmp3));
-	_tmp4 = NULL;
-	old_insert_block = (_tmp4 = analyzer->insert_block, (_tmp4 == NULL) ? NULL : vala_code_node_ref (_tmp4));
+	_tmp3_ = NULL;
+	old_symbol = (_tmp3_ = vala_semantic_analyzer_get_current_symbol (analyzer), (_tmp3_ == NULL) ? NULL : vala_code_node_ref (_tmp3_));
+	_tmp4_ = NULL;
+	old_insert_block = (_tmp4_ = analyzer->insert_block, (_tmp4_ == NULL) ? NULL : vala_code_node_ref (_tmp4_));
 	vala_semantic_analyzer_set_current_symbol (analyzer, (ValaSymbol*) self);
-	_tmp6 = NULL;
-	_tmp5 = NULL;
-	analyzer->insert_block = (_tmp6 = (_tmp5 = (ValaBlock*) self, (_tmp5 == NULL) ? NULL : vala_code_node_ref (_tmp5)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp6);
+	_tmp6_ = NULL;
+	_tmp5_ = NULL;
+	analyzer->insert_block = (_tmp6_ = (_tmp5_ = (ValaBlock*) self, (_tmp5_ == NULL) ? NULL : vala_code_node_ref (_tmp5_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp6_);
 	{
-		GeeList* _tmp7;
-		GeeIterator* _tmp8;
+		GeeList* _tmp7_;
+		GeeIterator* _tmp8_;
 		GeeIterator* _st_it;
-		_tmp7 = NULL;
-		_tmp8 = NULL;
-		_st_it = (_tmp8 = gee_iterable_iterator ((GeeIterable*) (_tmp7 = vala_block_get_statements ((ValaBlock*) self))), (_tmp7 == NULL) ? NULL : (_tmp7 = (gee_collection_object_unref (_tmp7), NULL)), _tmp8);
+		_tmp7_ = NULL;
+		_tmp8_ = NULL;
+		_st_it = (_tmp8_ = gee_iterable_iterator ((GeeIterable*) (_tmp7_ = vala_block_get_statements ((ValaBlock*) self))), (_tmp7_ == NULL) ? NULL : (_tmp7_ = (gee_collection_object_unref (_tmp7_), NULL)), _tmp8_);
 		while (gee_iterator_next (_st_it)) {
 			ValaStatement* st;
 			st = (ValaStatement*) gee_iterator_get (_st_it);
@@ -1381,12 +1380,12 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		(_st_it == NULL) ? NULL : (_st_it = (gee_collection_object_unref (_st_it), NULL));
 	}
 	{
-		GeeList* _tmp9;
-		GeeIterator* _tmp10;
+		GeeList* _tmp9_;
+		GeeIterator* _tmp10_;
 		GeeIterator* _local_it;
-		_tmp9 = NULL;
-		_tmp10 = NULL;
-		_local_it = (_tmp10 = gee_iterable_iterator ((GeeIterable*) (_tmp9 = vala_block_get_local_variables ((ValaBlock*) self))), (_tmp9 == NULL) ? NULL : (_tmp9 = (gee_collection_object_unref (_tmp9), NULL)), _tmp10);
+		_tmp9_ = NULL;
+		_tmp10_ = NULL;
+		_local_it = (_tmp10_ = gee_iterable_iterator ((GeeIterable*) (_tmp9_ = vala_block_get_local_variables ((ValaBlock*) self))), (_tmp9_ == NULL) ? NULL : (_tmp9_ = (gee_collection_object_unref (_tmp9_), NULL)), _tmp10_);
 		while (gee_iterator_next (_local_it)) {
 			ValaLocalVariable* local;
 			local = (ValaLocalVariable*) gee_iterator_get (_local_it);
@@ -1396,10 +1395,10 @@ static gboolean vala_switch_section_real_check (ValaCodeNode* base, ValaSemantic
 		(_local_it == NULL) ? NULL : (_local_it = (gee_collection_object_unref (_local_it), NULL));
 	}
 	vala_semantic_analyzer_set_current_symbol (analyzer, old_symbol);
-	_tmp12 = NULL;
-	_tmp11 = NULL;
-	analyzer->insert_block = (_tmp12 = (_tmp11 = old_insert_block, (_tmp11 == NULL) ? NULL : vala_code_node_ref (_tmp11)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp12);
-	return (_tmp13 = !vala_code_node_get_error ((ValaCodeNode*) self), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_insert_block == NULL) ? NULL : (old_insert_block = (vala_code_node_unref (old_insert_block), NULL)), _tmp13);
+	_tmp12_ = NULL;
+	_tmp11_ = NULL;
+	analyzer->insert_block = (_tmp12_ = (_tmp11_ = old_insert_block, (_tmp11_ == NULL) ? NULL : vala_code_node_ref (_tmp11_)), (analyzer->insert_block == NULL) ? NULL : (analyzer->insert_block = (vala_code_node_unref (analyzer->insert_block), NULL)), _tmp12_);
+	return (_tmp13_ = !vala_code_node_get_error ((ValaCodeNode*) self), (old_symbol == NULL) ? NULL : (old_symbol = (vala_code_node_unref (old_symbol), NULL)), (old_insert_block == NULL) ? NULL : (old_insert_block = (vala_code_node_unref (old_insert_block), NULL)), _tmp13_);
 }
 
 
