@@ -1,6 +1,6 @@
 /* valaswitchstatement.vala
  *
- * Copyright (C) 2006-2007  Jürg Billeter
+ * Copyright (C) 2006-2009  Jürg Billeter
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -156,6 +156,36 @@ typedef struct _ValaSwitchSectionClass ValaSwitchSectionClass;
 
 typedef struct _ValaSourceReference ValaSourceReference;
 typedef struct _ValaSourceReferenceClass ValaSourceReferenceClass;
+
+#define VALA_TYPE_VALUE_TYPE (vala_value_type_get_type ())
+#define VALA_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_VALUE_TYPE, ValaValueType))
+#define VALA_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+#define VALA_IS_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_VALUE_TYPE))
+#define VALA_IS_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_VALUE_TYPE))
+#define VALA_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_VALUE_TYPE, ValaValueTypeClass))
+
+typedef struct _ValaValueType ValaValueType;
+typedef struct _ValaValueTypeClass ValaValueTypeClass;
+
+#define VALA_TYPE_INTEGER_TYPE (vala_integer_type_get_type ())
+#define VALA_INTEGER_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_INTEGER_TYPE, ValaIntegerType))
+#define VALA_INTEGER_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_INTEGER_TYPE, ValaIntegerTypeClass))
+#define VALA_IS_INTEGER_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_INTEGER_TYPE))
+#define VALA_IS_INTEGER_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_INTEGER_TYPE))
+#define VALA_INTEGER_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_INTEGER_TYPE, ValaIntegerTypeClass))
+
+typedef struct _ValaIntegerType ValaIntegerType;
+typedef struct _ValaIntegerTypeClass ValaIntegerTypeClass;
+
+#define VALA_TYPE_ENUM_VALUE_TYPE (vala_enum_value_type_get_type ())
+#define VALA_ENUM_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), VALA_TYPE_ENUM_VALUE_TYPE, ValaEnumValueType))
+#define VALA_ENUM_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), VALA_TYPE_ENUM_VALUE_TYPE, ValaEnumValueTypeClass))
+#define VALA_IS_ENUM_VALUE_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), VALA_TYPE_ENUM_VALUE_TYPE))
+#define VALA_IS_ENUM_VALUE_TYPE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), VALA_TYPE_ENUM_VALUE_TYPE))
+#define VALA_ENUM_VALUE_TYPE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), VALA_TYPE_ENUM_VALUE_TYPE, ValaEnumValueTypeClass))
+
+typedef struct _ValaEnumValueType ValaEnumValueType;
+typedef struct _ValaEnumValueTypeClass ValaEnumValueTypeClass;
 typedef struct _ValaCodeVisitorPrivate ValaCodeVisitorPrivate;
 
 #define VALA_TYPE_SOURCE_FILE (vala_source_file_get_type ())
@@ -1019,7 +1049,6 @@ struct _ValaSemanticAnalyzer {
 	ValaDataType* ulong_type;
 	ValaDataType* size_t_type;
 	ValaDataType* ssize_t_type;
-	ValaDataType* uint64_type;
 	ValaDataType* int8_type;
 	ValaDataType* unichar_type;
 	ValaDataType* double_type;
@@ -1092,6 +1121,9 @@ void vala_code_node_set_checked (ValaCodeNode* self, gboolean value);
 gboolean vala_code_node_check (ValaCodeNode* self, ValaSemanticAnalyzer* analyzer);
 void vala_code_node_set_error (ValaCodeNode* self, gboolean value);
 ValaDataType* vala_expression_get_value_type (ValaExpression* self);
+GType vala_value_type_get_type (void);
+GType vala_integer_type_get_type (void);
+GType vala_enum_value_type_get_type (void);
 gboolean vala_data_type_compatible (ValaDataType* self, ValaDataType* target_type);
 gpointer vala_source_file_ref (gpointer instance);
 void vala_source_file_unref (gpointer instance);
@@ -1266,6 +1298,7 @@ static void vala_switch_statement_real_replace_expression (ValaCodeNode* base, V
 static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemanticAnalyzer* analyzer) {
 	ValaSwitchStatement * self;
 	gboolean _tmp2_;
+	gboolean _tmp3_;
 	self = (ValaSwitchStatement*) base;
 	g_return_val_if_fail (analyzer != NULL, FALSE);
 	if (vala_code_node_get_checked ((ValaCodeNode*) self)) {
@@ -1277,7 +1310,13 @@ static gboolean vala_switch_statement_real_check (ValaCodeNode* base, ValaSemant
 		return FALSE;
 	}
 	_tmp2_ = FALSE;
-	if (!vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->uint64_type)) {
+	_tmp3_ = FALSE;
+	if (!VALA_IS_INTEGER_TYPE (vala_expression_get_value_type (vala_switch_statement_get_expression (self)))) {
+		_tmp3_ = !VALA_IS_ENUM_VALUE_TYPE (vala_expression_get_value_type (vala_switch_statement_get_expression (self)));
+	} else {
+		_tmp3_ = FALSE;
+	}
+	if (_tmp3_) {
 		_tmp2_ = !vala_data_type_compatible (vala_expression_get_value_type (vala_switch_statement_get_expression (self)), analyzer->string_type);
 	} else {
 		_tmp2_ = FALSE;
