@@ -234,10 +234,10 @@ void vala_tuple_add_expression (ValaTuple* self, ValaExpression* expr) {
 
 
 GeeList* vala_tuple_get_expressions (ValaTuple* self) {
-	GeeList* _tmp0;
+	GeeList* _tmp0_;
 	g_return_val_if_fail (self != NULL, NULL);
-	_tmp0 = NULL;
-	return (_tmp0 = self->priv->expression_list, (_tmp0 == NULL) ? NULL : gee_collection_object_ref (_tmp0));
+	_tmp0_ = NULL;
+	return (_tmp0_ = self->priv->expression_list, (_tmp0_ == NULL) ? NULL : gee_collection_object_ref (_tmp0_));
 }
 
 
